import React from 'react';
import { shallow } from 'enzyme';
import { Link } from 'react-router-dom';
import { A as fromLib } from '../..';
import Icon from '../Icon';
import A from './A';
var props = {
  href: 'http://www.google.com',
  text: 'link text'
};
var wrapper;
describe('A', function () {
  beforeEach(function () {
    wrapper = shallow(
    /*#__PURE__*/
    React.createElement(A, props));
  });
  it('should be exported as part of the library', function () {
    expect(fromLib).toEqual(A);
  });
  it('should render correctly', function () {
    expect(wrapper).toMatchSnapshot();
  });
  it('should render children if no `text`', function () {
    wrapper.setProps({
      text: '',
      children: 'children...'
    });
    expect(wrapper.text()).toEqual('children...');
  });
  describe('external links', function () {
    it('should use an `a` tag', function () {
      var tag = wrapper.type();
      expect(tag).toBe('a');
    });
    it('should open in a new tab', function () {
      var target = wrapper.prop('target');
      expect(target).toBe('_blank');
    });
  });
  describe('internal links', function () {
    it('should use a `Link` tag', function () {
      wrapper.setProps({
        to: '/testPath',
        href: undefined
      });
      var tag = wrapper.type();
      expect(tag).toBe(Link);
    });
  });
  describe('icon links', function () {
    it('should render links as icons', function () {
      wrapper.setProps({
        iconProps: {
          name: 'test',
          srOnly: 'test-sr'
        },
        text: null
      });
      expect(wrapper.find(Icon).length).toBe(1);
    });
  });
  it('should pass additional props', function () {
    wrapper.setProps({
      id: 'testId',
      type: 'submit',
      variant: 'primary'
    });
    expect(wrapper.prop('id')).toBe('testId');
    expect(wrapper.prop('type')).toBe('submit');
    expect(wrapper.prop('variant')).toBe('primary');
  });
});