import React from 'react';
import { shallow } from 'enzyme';
import App from './App';
var props = {
  history: {
    push: jest.fn()
  }
};
var wrapper;
var instance;
describe('App', function () {
  beforeEach(function () {
    wrapper = shallow(
    /*#__PURE__*/
    React.createElement(App, props));
    instance = wrapper.instance();
  });
  describe('onScroll', function () {
    it('should do nothing if scrolled up and return top is not visible', function () {
      window.scrollY = 0;
      instance.onScroll();
      expect(wrapper.state('returnTopVisible')).toBeFalsy();
    });
    it('should set return top as visible if scrolled up and return top is visible', function () {
      window.scrollY = 0;
      wrapper.setState({
        returnTopVisible: true
      });
      instance.onScroll();
      expect(wrapper.state('returnTopVisible')).toBeFalsy();
    });
    it('should set return top as visible if scrolled down and return top is not visible', function () {
      window.scrollY = 99999;
      instance.onScroll();
      expect(wrapper.state('returnTopVisible')).toBeTruthy();
    });
    it('should do nothing if scrolled down and return top is visible', function () {
      window.scrollY = 99999;
      wrapper.setState({
        returnTopVisible: true
      });
      instance.onScroll();
      expect(wrapper.state('returnTopVisible')).toBeTruthy();
    });
  });
  describe('renderReturnTop', function () {
    it('should render a component', function () {
      var ReturnTop = shallow(instance.renderReturnTop());
      expect(ReturnTop.children.length).not.toBe(0);
    });
    it('should attach the `is-visible` class if visible', function () {
      wrapper.setState({
        returnTopVisible: true
      });
      var ReturnTop = shallow(instance.renderReturnTop());
      expect(ReturnTop.prop('className')).toMatch(/is-visible/);
    });
    it('should call `onClickReturnTop` when clicked', function () {
      instance.onClickReturnTop = jest.fn();
      var ReturnTop = shallow(instance.renderReturnTop());
      ReturnTop.prop('onClick')();
      expect(instance.onClickReturnTop).toBeCalled();
    });
  });
  describe('renderHeader', function () {
    it('should render the custom routing if `renderHeader` passed', function () {
      var renderHeader = function renderHeader() {
        return (
          /*#__PURE__*/
          React.createElement("header", null, "custom header")
        );
      };

      wrapper.setProps({
        renderHeader: renderHeader
      });
      var isSame = shallow(instance.renderHeader()).equals(renderHeader());
      expect(isSame).toBeTruthy();
    });
  });
  describe('renderRouting', function () {
    it('should render the custom routing if `renderRouting` passed', function () {
      var renderRouting = function renderRouting() {
        return (
          /*#__PURE__*/
          React.createElement("div", null, "custom routing")
        );
      };

      wrapper.setProps({
        renderRouting: renderRouting
      });
      var isSame = shallow(instance.renderRouting()).equals(renderRouting());
      expect(isSame).toBeTruthy();
    });
  });
  describe('renderFooter', function () {
    it('should render the custom footer if `renderFooter` passed', function () {
      var renderFooter = function renderFooter() {
        return (
          /*#__PURE__*/
          React.createElement("footer", null, "custom footer")
        );
      };

      wrapper.setProps({
        renderFooter: renderFooter
      });
      var isSame = shallow(instance.renderFooter()).equals(renderFooter());
      expect(isSame).toBeTruthy();
    });
  });
  describe('render', function () {
    it('should render correctly', function () {
      expect(wrapper).toMatchSnapshot();
    });
    it('should allow a custom router to be used that is passed the history', function () {
      var CustomRouter = function CustomRouter() {
        return (
          /*#__PURE__*/
          React.createElement("div", null, "in custom routing...")
        );
      };

      wrapper.setProps({
        router: CustomRouter
      });
      expect(wrapper.find(CustomRouter).length).toBe(1);
      expect(wrapper.find(CustomRouter).prop('history')).toBe(props.history);
    });
  });
});