import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import { ApplicationInsights, SeverityLevel } from '@microsoft/applicationinsights-web';
import { ReactPlugin } from '@microsoft/applicationinsights-react-js';
var reactPlugin = null;
var appInsights = null;
var loggingLevel = null;

var AppInsightsService = function AppInsightsService() {
  var initialize = function initialize(instrumentationKey, browserHistory, severityLevel) {
    if (!browserHistory) {
      throw new Error('Could not initialize Application insights, browserHistory is required as a parameter');
    }

    if (!instrumentationKey) {
      throw new Error('Instrumentation key was not added as a parameter');
    }

    loggingLevel = severityLevel;
    reactPlugin = new ReactPlugin();
    appInsights = new ApplicationInsights({
      config: {
        instrumentationKey: instrumentationKey,
        maxBatchInterval: 0,
        disableFetchTracking: false,
        extensions: [reactPlugin],
        extensionConfig: _defineProperty({}, reactPlugin.identifier, {
          history: browserHistory
        })
      }
    });
    appInsights.loadAppInsights();
  };

  return {
    reactPlugin: reactPlugin,
    appInsights: appInsights,
    initialize: initialize
  };
};

var providerCheck = function providerCheck() {
  if (!appInsights) {
    throw new Error('Application Insights provider required');
  }
};

export var trackEvent = function trackEvent(name) {
  providerCheck();
  appInsights.trackEvent({
    name: name
  });
};
export var trackException = function trackException(exception) {
  providerCheck();
  appInsights.trackException({
    exception: exception
  });
};
export var trackTrace = function trackTrace(message, severityLevel, properties) {
  providerCheck();

  if (!severityLevel || severityLevel >= loggingLevel) {
    appInsights.trackTrace({
      message: message,
      severityLevel: severityLevel,
      properties: properties
    });
  }
};
export var severityLevel = SeverityLevel;
export var ai = AppInsightsService();
export var getAppInsights = function getAppInsights() {
  return appInsights;
};