import React from 'react';
import Button from '../Button';
import ErrorMessage from './ErrorMessage';
import LoadingIndicator from './LoadingIndicator';
/**
 * Async sections have a loading indicator if they take too long
 * to load, and display an error message for errors
 *
 * access the `data-status` attribute for the status of this
 * component (error, loading, or loaded)
 */

var Async = function Async(props) {
  var children = props.children,
      error = props.error,
      onDismiss = props.onDismiss,
      btnProps = props.btnProps,
      isLoading = props.isLoading,
      delay = props.delay;
  var status;

  if (error) {
    status = 'error';
  } else if (isLoading) {
    status = 'loading';
  } else {
    status = 'loaded';
  }

  return (
    /*#__PURE__*/
    React.createElement("div", {
      "data-test": 'async',
      "data-status": status
    },
    /*#__PURE__*/
    React.createElement(ErrorMessage, {
      error: error,
      onDismiss: onDismiss,
      btnProps: btnProps
    },
    /*#__PURE__*/
    React.createElement(LoadingIndicator, {
      isLoading: isLoading,
      delay: delay
    }, children)))
  );
};

Async.defaultProps = {
  btnProps: undefined,
  children: null,
  delay: 200,
  error: null,
  isLoading: false,
  onDismiss: function onDismiss() {}
};
export default Async;