import _objectSpread from "@babel/runtime/helpers/esm/objectSpread2";
import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
import React from 'react';
import { fieldInputPropTypes, fieldMetaPropTypes } from 'redux-form';
import classNames from 'classnames';
import FieldError from './FieldError';
import FieldWarning from './FieldWarning';
import FieldHelp from './FieldHelp'; // HOC that attaches a label, error message,
// help block, and attaches props such as aria labels
// Targeted use at redux form

export var withFieldWrapper = function withFieldWrapper(Component) {
  var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

  var WrappedField = function WrappedField(props) {
    var className = props.className,
        disabled = props.disabled,
        errorIdProp = props.errorId,
        helpIdProp = props.helpId,
        warningIdProp = props.warningId,
        helpText = props.helpText,
        input = props.input,
        label = props.label,
        meta = props.meta,
        required = props.required,
        tooltip = props.tooltip,
        rest = _objectWithoutProperties(props, ["className", "disabled", "errorId", "helpId", "warningId", "helpText", "input", "label", "meta", "required", "tooltip"]);

    var renderError = options.renderError,
        renderHelp = options.renderHelp,
        renderWarning = options.renderWarning;
    var touched = meta.touched,
        error = meta.error,
        warning = meta.warning;
    var name = input.name;
    var errorId = errorIdProp || "".concat(name, "--error");
    var helpId = helpIdProp || "".concat(name, "--help");
    var warningId = warningIdProp || "".concat(name, "--warning");
    var errorMessage = '';

    if (touched && error) {
      errorMessage = error;
    }

    var warningMessage = '';

    if (touched && warning) {
      warningMessage = warning;
    }

    var cn = classNames(['form-group', className, {
      disabled: disabled
    }, {
      'has-error': errorMessage
    }]);
    var ariaDescBy;
    var ariaInvalid = 'false';

    if (errorMessage || helpText) {
      ariaDescBy = '';

      if (errorMessage) {
        ariaDescBy += errorId;
        ariaInvalid = 'true';
      }

      if (helpText) {
        ariaDescBy += helpId;
      }
    }

    var fieldProps = _objectSpread(_objectSpread({
      'aria-describedby': ariaDescBy,
      'aria-invalid': ariaInvalid,
      disabled: disabled,
      label: label,
      required: required,
      tooltip: tooltip
    }, input), rest);

    var errorProps = {
      errorId: errorId,
      errorMessage: errorMessage
    };
    var warningProps = {
      warningId: warningId,
      warningMessage: warningMessage
    };
    var helpProps = {
      helpId: helpId,
      helpText: helpText
    };
    return (
      /*#__PURE__*/
      React.createElement("div", {
        className: cn
      },
      /*#__PURE__*/
      React.createElement(Component, Object.assign({
        id: name
      }, fieldProps)), errorMessage && (renderError ? renderError(errorProps) :
      /*#__PURE__*/
      React.createElement(FieldError, errorProps)), !errorMessage && warningMessage && (renderWarning ? renderWarning(warningProps) :
      /*#__PURE__*/
      React.createElement(FieldWarning, warningProps)), helpText && (renderHelp ? renderHelp(helpProps) :
      /*#__PURE__*/
      React.createElement(FieldHelp, helpProps)))
    );
  };

  WrappedField.defaultProps = {
    className: '',
    disabled: false,
    errorId: null,
    helpText: '',
    helpId: null,
    label: '',
    required: false,
    tooltip: null,
    warningId: null
  };
  return WrappedField;
};
export default withFieldWrapper;