import _toConsumableArray from "@babel/runtime/helpers/esm/toConsumableArray";
import React from 'react';
import classNames from 'classnames';
import * as propUtils from '../../utils/propTypes'; // handle changing array value in redux form

export var handleChange = function handleChange(_ref) {
  var value = _ref.value,
      values = _ref.values,
      onChange = _ref.onChange;
  return function (event) {
    var newValues = _toConsumableArray(values); // first element is blank, remove it


    if (newValues[0] === '') {
      newValues.shift();
    } // is checked, add it to array


    if (event.target.checked) {
      newValues.push(value);
    } else {
      // not checked, remove from array
      newValues.splice(newValues.indexOf(value), 1);
    }

    return onChange(newValues);
  };
}; // individual checkbox, applies state-template styling

var Checkbox = function Checkbox(props) {
  var ariaDescribedby = props['aria-describedby'],
      ariaInvalid = props['aria-invalid'],
      disabled = props.disabled,
      inline = props.inline,
      name = props.name,
      onBlur = props.onBlur,
      onChange = props.onChange,
      onFocus = props.onFocus,
      option = props.option,
      value = props.value,
      variant = props.variant;
  var values = Array.isArray(value) ? value : [value];
  var id = "".concat(name, "-").concat(option.value);
  var inputProps = {
    'aria-describedby': ariaDescribedby,
    'aria-invalid': ariaInvalid,
    checked: values.includes(option.value),
    disabled: disabled,
    id: id,
    name: name,
    type: 'checkbox'
  };

  if (onBlur) {
    inputProps.onBlur = function () {
      return onBlur(value);
    };
  }

  if (onChange) {
    inputProps.onChange = handleChange({
      value: option.value,
      values: values,
      onChange: onChange
    });
  }

  if (onFocus) {
    inputProps.onFocus = function () {
      return onFocus(value);
    };
  }

  var cn = classNames(['check', option.className]);

  if (variant) {
    return (
      /*#__PURE__*/
      React.createElement("label", {
        "data-test": 'field__checkbox',
        className: cn,
        htmlFor: id
      },
      /*#__PURE__*/
      React.createElement("input", Object.assign({
        className: 'hidden-up pos-abs top-0 left-0'
      }, inputProps)),
      /*#__PURE__*/
      React.createElement("span", {
        className: "btn btn-md btn-block color-white--checked bg-".concat(variant, "--checked rounded-0")
      }, option.label))
    );
  }

  cn = classNames(['p-l-md m-l-0 m-r-md', option.className, inline ? 'form-check-inline' : 'form-check']);
  return (
    /*#__PURE__*/
    React.createElement("label", {
      "data-test": 'field__checkbox',
      className: cn,
      htmlFor: id
    },
    /*#__PURE__*/
    React.createElement("input", Object.assign({
      className: 'hidden-up pos-abs'
    }, inputProps)),
    /*#__PURE__*/
    React.createElement("div", {
      className: 'check-icon-checkbox',
      "aria-hidden": true
    },
    /*#__PURE__*/
    React.createElement("i", {
      className: 'ca-gov-icon-check-mark'
    })), option.label)
  );
};

Checkbox.defaultProps = {
  'aria-describedby': null,
  'aria-invalid': 'false',
  disabled: false,
  inline: false,
  onBlur: null,
  onChange: null,
  onFocus: null,
  variant: null
};
export default Checkbox;