import React from 'react';
import { shallow } from 'enzyme';
import Checkbox, { handleChange } from './Checkbox';
var props = {
  'aria-describedby': 'aria-desc-id',
  'aria-invalid': 'false',
  disabled: false,
  inline: false,
  name: 'test-name',
  onBlur: jest.fn(),
  onChange: jest.fn(),
  onFocus: jest.fn(),
  option: {
    label: 'label-1',
    value: 'value-1',
    className: 'option-class'
  },
  value: 'value-1',
  variant: null
};
var wrapper;
describe('Checkbox', function () {
  beforeEach(function () {
    wrapper = shallow(
    /*#__PURE__*/
    React.createElement(Checkbox, props));
  });
  it('should render correctly', function () {
    expect(wrapper).toMatchSnapshot();
  });
  it('should allow variants', function () {
    wrapper.setProps({
      variant: 'primary'
    });
    var className = wrapper.find('span').prop('className');
    expect(className).toMatch(/bg-primary/);
  });
  it('should be `checked` for matching string values', function () {
    wrapper.setProps({
      value: props.value
    });
    expect(wrapper.find('checked')).toBeTruthy();
  });
  it('should be `checked` for matching values in an array', function () {
    wrapper.setProps({
      value: [props.value]
    });
    expect(wrapper.find('checked')).toBeTruthy();
  });
  var onChange;
  describe('handleChange', function () {
    beforeEach(function () {
      onChange = jest.fn();
    });
    it('should remove blank values from the start of the array', function () {
      var event = {
        target: {
          checked: false
        }
      };
      handleChange({
        value: 'v1',
        values: ['', 'v 1'],
        onChange: onChange
      })(event);
      expect(onChange).toBeCalledWith([]);
    });
    it('should add a value to the end of the array if checked', function () {
      var event = {
        target: {
          checked: true
        }
      };
      handleChange({
        value: 'v 1',
        values: [],
        onChange: onChange
      })(event);
      expect(onChange).toBeCalledWith(['v 1']);
    });
    it('should remove a value if not checked', function () {
      var event = {
        target: {
          checked: false
        }
      };
      handleChange({
        value: 'v 2',
        values: ['v 1', 'v 2', 'v 3'],
        onChange: onChange
      })(event);
      expect(onChange).toBeCalledWith(['v 1', 'v 3']);
    });
  });
});