import _classCallCheck from "@babel/runtime/helpers/esm/classCallCheck";
import _createClass from "@babel/runtime/helpers/esm/createClass";
import _inherits from "@babel/runtime/helpers/esm/inherits";
import _possibleConstructorReturn from "@babel/runtime/helpers/esm/possibleConstructorReturn";
import _getPrototypeOf from "@babel/runtime/helpers/esm/getPrototypeOf";

function _createSuper(Derived) {
  function isNativeReflectConstruct() {
    if (typeof Reflect === "undefined" || !Reflect.construct) return false;
    if (Reflect.construct.sham) return false;
    if (typeof Proxy === "function") return true;

    try {
      Date.prototype.toString.call(Reflect.construct(Date, [], function () {}));
      return true;
    } catch (e) {
      return false;
    }
  }

  return function () {
    var Super = _getPrototypeOf(Derived),
        result;

    if (isNativeReflectConstruct()) {
      var NewTarget = _getPrototypeOf(this).constructor;

      result = Reflect.construct(Super, arguments, NewTarget);
    } else {
      result = Super.apply(this, arguments);
    }

    return _possibleConstructorReturn(this, result);
  };
}

import React from 'react';
import classNames from 'classnames';
import { isEmptyRadio } from '../../utils/validate';
import { keyCodes } from '../../utils/aria';
import * as propUtils from '../../utils/propTypes';
import { withField, FieldLabel } from '../Field';
import Icon from '../Icon';
/**
 * An accessible combo box field that allows inputing a value to search through a list.
 *
 * Based off https://www.w3.org/TR/wai-aria-practices/examples/combobox/aria1.1pattern/listbox-combo.html
 * to provide accessibility features.
 *
 * Extends [HTMLSelectElement](https://developer.mozilla.org/en-US/docs/Web/API/HTMLSelectElement) properties (id, data-*, etc)
 */

export var FieldComboBox =
/*#__PURE__*/
function (_React$Component) {
  _inherits(FieldComboBox, _React$Component);

  var _super = _createSuper(FieldComboBox);

  function FieldComboBox(props) {
    var _this;

    _classCallCheck(this, FieldComboBox);

    _this = _super.call(this, props);

    _this.setItemFromValue = function () {
      var _this$props = _this.props,
          value = _this$props.value,
          options = _this$props.options;
      var item = options.find(function (option) {
        return option.value === value;
      });

      _this.setLabel(item);
    };

    _this.showListbox = function () {
      var onShow = _this.props.onShow;
      var showListbox = _this.state.showListbox;

      if (!showListbox) {
        _this.setState({
          activeIndex: 0,
          focusedIndex: 0,
          showListbox: true
        });

        if (onShow) onShow();
      }
    };

    _this.hideListbox = function () {
      var onHide = _this.props.onHide;
      var showListbox = _this.state.showListbox;

      if (showListbox) {
        _this.setState({
          activeIndex: -1,
          showListbox: false
        });

        if (onHide) onHide();
      }
    };

    _this.updateFilteredList = function () {
      var options = _this.props.options;
      var input = _this.inputRef.current;
      var value = input.value.toLowerCase();
      var filteredList = options.filter(function (x) {
        return !x.hidden && x.label.toLowerCase().indexOf(value) > -1;
      });

      _this.setState({
        filteredList: filteredList
      }, _this.positionList);
    };

    _this.scrollToFocus = function (index) {
      var listbox = _this.listboxRef.current;

      if (listbox) {
        var selectedItem = listbox.children[index];

        if (selectedItem) {
          listbox.scrollTop = selectedItem.offsetTop;
        }
      }
    };

    _this.positionList = function () {
      var listbox = _this.listboxRef.current;
      var input = _this.inputRef.current;
      if (!listbox) return;

      var _listbox$getBoundingC = listbox.getBoundingClientRect(),
          top = _listbox$getBoundingC.top,
          bottom = _listbox$getBoundingC.bottom,
          height = _listbox$getBoundingC.height;

      if (top < 0) {
        // scrolled off top, position below input
        listbox.style.top = "".concat(input.offsetHeight, "px");
      } else if (bottom > window.innerHeight) {
        // scrolled off bottom, position above input
        listbox.style.top = "-".concat(height, "px");
      }
    };

    _this.getItemAt = function (index) {
      var filteredList = _this.state.filteredList;
      return filteredList[index];
    };

    _this.setLabel = function () {
      var item = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      var label = item.label;
      var input = _this.inputRef.current;

      if (input) {
        input.value = label || '';
      }
    };

    _this.setValue = function () {
      var item = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      var onChange = _this.props.onChange;
      onChange(item.value);
    };

    _this.onClickOutside = function (event) {
      var target = event.target;
      var wrapper = _this.wrapperRef.current; // if event is outside this component hide the listbox

      if (target !== wrapper && !wrapper.contains(target)) {
        _this.hideListbox();
      }
    };

    _this.onBlur = function () {
      var focusedIndex = _this.state.focusedIndex;

      var item = _this.getItemAt(focusedIndex);

      _this.setLabel(item);

      _this.setValue(item);
    };

    _this.onFocus = function () {
      var activeIndex = _this.state.activeIndex;

      if (activeIndex >= 0) {
        var activeItem = _this.getItemAt(activeIndex);

        _this.onSelectItem(activeItem);
      }
    };

    _this.onKeyDown = function (event) {
      var id = _this.props.id;
      var _this$state = _this.state,
          activeIndex = _this$state.activeIndex,
          filteredList = _this$state.filteredList;
      var key = event.which || event.keyCode; // [ESC] pressed - hide listbox

      if (key === keyCodes.esc) {
        _this.hideListbox();

        return;
      }

      var newActiveIndex = activeIndex < 0 ? 0 : activeIndex;

      switch (key) {
        // up, move active up 1 or loop to end
        case keyCodes.up:
          newActiveIndex -= 1;

          if (newActiveIndex < 0) {
            newActiveIndex = filteredList.length - 1;
          }

          break;
        // up, move active down 1 or loop to begining

        case keyCodes.down:
          newActiveIndex += 1;

          if (newActiveIndex > filteredList.length - 1) {
            newActiveIndex = 0;
          }

          break;

        case keyCodes.enter:
          event.preventDefault();

          _this.onSelectItem(_this.getItemAt(newActiveIndex));

          return;

        case keyCodes.tab:
        case keyCodes.tab && event.shiftKey:
          _this.hideListbox();

          return;

        default:
          break;
      }

      _this.showListbox();

      var activeItem = _this.getItemAt(newActiveIndex);

      var input = _this.inputRef.current;

      if (activeItem) {
        var itemId = "".concat(id, "-item-").concat(newActiveIndex);
        input.setAttribute('aria-activedescendant', itemId);

        _this.scrollToFocus(newActiveIndex);
      } else {
        input.setAttribute('aria-activedescendant', '');
      }

      _this.setState({
        activeIndex: newActiveIndex,
        focusedIndex: newActiveIndex
      });
    };

    _this.onKeyUp = function (event) {
      var key = event.which || event.keyCode;

      switch (key) {
        case keyCodes.down:
        case keyCodes.enter:
        case keyCodes.esc:
        case keyCodes.up:
          event.preventDefault();
          return;

        default:
          _this.updateFilteredList();

      }
    };

    _this.onSelectItem = function (item) {
      var onSelect = _this.props.onSelect;

      _this.hideListbox();

      _this.setValue(item);

      if (onSelect) onSelect(item);
    };

    _this.onClickIcon = function () {
      var showListbox = _this.state.showListbox;
      var input = _this.inputRef.current;

      if (showListbox) {
        _this.hideListbox();
      } else {
        _this.showListbox();

        _this.updateFilteredList();

        input.focus();
      }
    };

    _this.state = {
      activeIndex: -1,
      focusedIndex: -1,
      filteredList: props.options,
      showListbox: false
    };
    _this.wrapperRef = React.createRef();
    _this.inputRef = props.inputRef || React.createRef();
    _this.listboxRef = React.createRef();
    return _this;
  }

  _createClass(FieldComboBox, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      this.setItemFromValue();
      document.body.addEventListener('click', this.onClickOutside);
    }
  }, {
    key: "componentDidUpdate",
    value: function componentDidUpdate(prevProps) {
      var value = this.props.value;

      if (value !== prevProps.value) {
        this.setItemFromValue();
      }
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      document.body.removeEventListener('click', this.onClickOutside);
    }
  }, {
    key: "render",
    value: function render() {
      var _this2 = this;

      var _this$props2 = this.props,
          className = _this$props2.className,
          disabled = _this$props2.disabled,
          id = _this$props2.id,
          label = _this$props2.label,
          name = _this$props2.name,
          required = _this$props2.required,
          tooltip = _this$props2.tooltip;
      var _this$state2 = this.state,
          activeIndex = _this$state2.activeIndex,
          filteredList = _this$state2.filteredList,
          showListbox = _this$state2.showListbox;
      var cn = classNames(['field__combo-box', className]);
      var listboxId = "".concat(id, "-listbox");
      /* eslint-disable jsx-a11y/click-events-have-key-events */

      /* eslint-disable jsx-a11y/role-has-required-aria-props */

      return (
        /*#__PURE__*/
        React.createElement(React.Fragment, null,
        /*#__PURE__*/
        React.createElement(FieldLabel, {
          htmlFor: name,
          label: label,
          name: name,
          required: required,
          tooltip: tooltip
        }),
        /*#__PURE__*/
        React.createElement("div", {
          "data-test": 'field__combo-box',
          className: cn,
          ref: this.wrapperRef
        },
        /*#__PURE__*/
        React.createElement("div", {
          "aria-expanded": showListbox,
          "aria-haspopup": 'listbox',
          "aria-owns": listboxId,
          id: "".concat(id, "-combobox"),
          role: 'combobox'
        },
        /*#__PURE__*/
        React.createElement("input", {
          "aria-controls": listboxId,
          className: 'form-control',
          disabled: disabled,
          id: id,
          onBlur: this.onBlur,
          onFocus: this.onFocus,
          onKeyDown: this.onKeyDown,
          onKeyUp: this.onKeyUp,
          ref: this.inputRef,
          type: 'text'
        }),
        /*#__PURE__*/
        React.createElement(Icon, {
          hidden: disabled,
          name: 'triangle-down',
          "data-test": 'field__combo-box-icon',
          className: 'field__combo-box-icon',
          onClick: this.onClickIcon
        })),
        /*#__PURE__*/
        React.createElement("ul", {
          "aria-label": label,
          className: 'field__combo-box--listbox',
          id: listboxId,
          role: 'listbox',
          ref: this.listboxRef,
          hidden: !showListbox
        }, filteredList.map(function (option, i) {
          var isActive = activeIndex === i;
          var activeClass = isActive ? 'bg-primary' : '';
          return (
            /*#__PURE__*/
            React.createElement("li", {
              key: option.value,
              role: 'option',
              "aria-selected": isActive,
              className: activeClass,
              onClick: function onClick() {
                return _this2.onSelectItem(option);
              },
              id: "".concat(id, "-item-").concat(i)
            }, option.label)
          );
        })),
        /*#__PURE__*/
        React.createElement("input", {
          type: 'hidden',
          name: name,
          disabled: disabled
        })))
      );
      /* eslint-enable jsx-a11y/click-events-have-key-events */

      /* eslint-enable jsx-a11y/role-has-required-aria-props */
    }
  }]);

  return FieldComboBox;
}(React.Component);
FieldComboBox.defaultProps = {
  'aria-invalid': 'false',
  className: null,
  disabled: false,
  id: null,
  inputRef: null,
  required: false,
  onHide: null,
  onShow: null,
  onSelect: null,
  tooltip: null,
  value: null
};
export default withField(isEmptyRadio)(FieldComboBox);