import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
import _classCallCheck from "@babel/runtime/helpers/esm/classCallCheck";
import _createClass from "@babel/runtime/helpers/esm/createClass";
import _inherits from "@babel/runtime/helpers/esm/inherits";
import _possibleConstructorReturn from "@babel/runtime/helpers/esm/possibleConstructorReturn";
import _getPrototypeOf from "@babel/runtime/helpers/esm/getPrototypeOf";

function _createSuper(Derived) {
  function isNativeReflectConstruct() {
    if (typeof Reflect === "undefined" || !Reflect.construct) return false;
    if (Reflect.construct.sham) return false;
    if (typeof Proxy === "function") return true;

    try {
      Date.prototype.toString.call(Reflect.construct(Date, [], function () {}));
      return true;
    } catch (e) {
      return false;
    }
  }

  return function () {
    var Super = _getPrototypeOf(Derived),
        result;

    if (isNativeReflectConstruct()) {
      var NewTarget = _getPrototypeOf(this).constructor;

      result = Reflect.construct(Super, arguments, NewTarget);
    } else {
      result = Super.apply(this, arguments);
    }

    return _possibleConstructorReturn(this, result);
  };
}

import React from 'react';
import Pikaday from 'pikaday';
import classNames from 'classnames';
import { isValidDate } from '../../utils/validate';
import { keyCodes } from '../../utils/aria';
import { isValid } from '../../utils/date';
import { withField, FieldLabel } from '../Field';
import Icon from '../Icon';
/**
 * Date picker field and label that applies state-template styling. Uses
 * the pikaday library for handling date picking.
 *
 * Refer to [this demo](https://whatsock.com/tsg/Coding%20Arena/ARIA%20Date%20Pickers/ARIA%20Date%20Picker%20%28Basic%29/demo.htm) for accesibility applied.
 *
 * Extends [HTMLInputElement](https://developer.mozilla.org/en-US/docs/Web/API/HTMLInputElement) properties (id, data-*, etc)
 */

export var FieldDate =
/*#__PURE__*/
function (_React$Component) {
  _inherits(FieldDate, _React$Component);

  var _super = _createSuper(FieldDate);

  function FieldDate(props, context) {
    var _this;

    _classCallCheck(this, FieldDate);

    _this = _super.call(this, props, context);

    _this.getDisplayDate = function (date) {
      if (isValid(date)) {
        return new Date(date).toISOString().slice(0, 10);
      }

      return '';
    };

    _this.getPickerDate = function (date) {
      if (isValid(date)) {
        var d = new Date(date);
        return new Date(d.getUTCFullYear(), d.getUTCMonth(), d.getUTCDate());
      }

      return '';
    };

    _this.setWeekStart = function () {
      var selected = new Date(_this.picker.getDate());
      selected.setDate(selected.getDate() - selected.getDay());

      _this.updateDate(selected);
    };

    _this.setWeekEnd = function () {
      var selected = new Date(_this.picker.getDate());
      var dayOfMonth = selected.getDate();
      var daysLeft = 6 - selected.getDay();
      selected.setDate(dayOfMonth + daysLeft);

      _this.updateDate(selected);
    };

    _this.setPrevMonth = function () {
      var selected = new Date(_this.picker.getDate());
      var month = selected.getMonth();
      var prevMonth = month === 1 ? 12 : month - 1;
      selected.setMonth(prevMonth);

      if (prevMonth === 12) {
        selected.setFullYear(selected.getFullYear() - 1);
      }

      _this.updateDate(selected);
    };

    _this.setNextMonth = function () {
      var selected = new Date(_this.picker.getDate());
      var month = selected.getMonth();
      var nextMonth = month === 12 ? 1 : month + 1;
      selected.setMonth(nextMonth);

      if (nextMonth === 1) {
        selected.setFullYear(selected.getFullYear() + 1);
      }

      _this.updateDate(selected);
    };

    _this.onChange = function (event) {
      var value = event.target.value;

      _this.setState({
        displayText: value
      });

      _this.updatePicker(value);
    };

    _this.onClose = function () {
      var _this$props = _this.props,
          onChange = _this$props.onChange,
          onBlur = _this$props.onBlur;

      var date = _this.picker.getDate(); // update passed in value


      if (onChange) {
        onChange(_this.getDisplayDate(date));
      }

      if (onBlur) {
        onBlur();
      } // update display field


      _this.updateDisplay(date);
    };

    _this.onKeyDown = function (event) {
      var value = _this.props.value;
      var keyCode = event.keyCode; // enter => select date

      if (keyCode === keyCodes.enter) {
        event.preventDefault();

        _this.picker.hide();
      } // esc => no action / do not update (revert to what value was)


      if (keyCode === keyCodes.esc) {
        event.preventDefault();

        _this.updatePicker(value);

        _this.picker.hide();
      } // home => go to beggining of row


      if (keyCode === keyCodes.home) {
        event.preventDefault();

        _this.setWeekStart();
      } // end => go to end of row


      if (keyCode === keyCodes.end) {
        event.preventDefault();

        _this.setWeekEnd();
      } // pagedown => go to previous month


      if (keyCode === keyCodes.pageDown) {
        event.preventDefault();

        _this.setPrevMonth();
      } // pageup => go to next month


      if (keyCode === keyCodes.pageUp) {
        event.preventDefault();

        _this.setNextMonth();
      }
    };

    _this.onKeyUp = function (event) {
      var keyCode = event.keyCode; // left, up, right, down => change date

      if ([keyCodes.up, keyCodes.down, keyCodes.left, keyCodes.right].includes(keyCode)) {
        event.preventDefault();

        _this.updateDisplay(_this.picker.getDate());
      }
    };

    _this.updateDisplay = function (value) {
      var displayText = _this.getDisplayDate(value);

      _this.setState({
        displayText: displayText
      });
    };

    _this.updatePicker = function (value) {
      var pickerValue = _this.getPickerDate(value);

      _this.picker.setDate(pickerValue);
    };

    _this.updateDate = function (value) {
      _this.updateDisplay(value);

      _this.updatePicker(value);
    };

    _this.initPikaday = function () {
      var _this$props2 = _this.props,
          value = _this$props2.value,
          minDate = _this$props2.minDate;
      _this.picker = new Pikaday({
        minDate: minDate,
        field: _this.pickerRef.current,
        onClose: _this.onClose,
        onSelect: _this.onSelect,
        yearRange: [new Date().getFullYear(), new Date().getFullYear() + 30],
        trigger: _this.displayRef.current,
        format: 'YYYY-MM-DD'
      });

      _this.updateDate(value);
    };

    _this.state = {
      displayText: ''
    };
    _this.pickerRef = React.createRef();
    _this.displayRef = props.inputRef || React.createRef();
    _this.picker = null;
    return _this;
  }

  _createClass(FieldDate, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      this.initPikaday();
    }
  }, {
    key: "componentDidUpdate",
    value: function componentDidUpdate(prevProps) {
      var value = this.props.value;

      if (value !== prevProps.value) {
        this.updateDate(value);
      }
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props3 = this.props,
          ariaDescBy = _this$props3['aria-describedby'],
          className = _this$props3.className,
          disabled = _this$props3.disabled,
          inputRef = _this$props3.inputRef,
          label = _this$props3.label,
          minDate = _this$props3.minDate,
          name = _this$props3.name,
          onFocus = _this$props3.onFocus,
          required = _this$props3.required,
          tooltip = _this$props3.tooltip,
          rest = _objectWithoutProperties(_this$props3, ["aria-describedby", "className", "disabled", "inputRef", "label", "minDate", "name", "onFocus", "required", "tooltip"]);

      var displayText = this.state.displayText;
      var cn = classNames(['field__date', className]);
      var infoId = "".concat(name, "--date-info");
      var describedby = ariaDescBy ? "".concat(ariaDescBy, " ").concat(infoId) : infoId;
      return (
        /*#__PURE__*/
        React.createElement(React.Fragment, null,
        /*#__PURE__*/
        React.createElement(FieldLabel, {
          htmlFor: name,
          label: label,
          name: name,
          required: required,
          tooltip: tooltip
        }),
        /*#__PURE__*/
        React.createElement("div", {
          "data-test": 'field__date',
          className: cn
        },
        /*#__PURE__*/
        React.createElement("input", Object.assign({}, rest, {
          autoComplete: 'off',
          "aria-describedby": describedby,
          className: 'form-control',
          "data-test": 'field__date-control',
          disabled: disabled,
          ref: this.displayRef,
          name: name,
          value: displayText,
          onChange: this.onChange,
          onBlur: this.onClose,
          onFocus: onFocus,
          onKeyDown: this.onKeyDown,
          onKeyUp: this.onKeyUp
        })),
        /*#__PURE__*/
        React.createElement("p", {
          id: infoId,
          className: 'hidden'
        }, "Type a YYYY-MM-DD format date, hit escape to cancel. Use the arrow keys for picking from the date picker. Use page up and down for navigating months. Use home and end for navigating weeks."),
        /*#__PURE__*/
        React.createElement(Icon, {
          hidden: disabled,
          name: 'calendar',
          "data-test": 'field__date-icon',
          className: 'field__date-icon'
        }),
        /*#__PURE__*/
        React.createElement("input", {
          type: 'hidden',
          ref: this.pickerRef,
          disabled: disabled
        })))
      );
    }
  }]);

  return FieldDate;
}(React.Component);
FieldDate.defaultProps = {
  'aria-describedby': null,
  'aria-invalid': 'false',
  className: null,
  disabled: false,
  id: null,
  inputRef: null,
  minDate: null,
  onChange: null,
  onBlur: null,
  onFocus: null,
  required: false,
  tooltip: null,
  value: null
};
export default withField(isValidDate)(FieldDate);