import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
import _classCallCheck from "@babel/runtime/helpers/esm/classCallCheck";
import _createClass from "@babel/runtime/helpers/esm/createClass";
import _inherits from "@babel/runtime/helpers/esm/inherits";
import _possibleConstructorReturn from "@babel/runtime/helpers/esm/possibleConstructorReturn";
import _getPrototypeOf from "@babel/runtime/helpers/esm/getPrototypeOf";

function _createSuper(Derived) {
  function isNativeReflectConstruct() {
    if (typeof Reflect === "undefined" || !Reflect.construct) return false;
    if (Reflect.construct.sham) return false;
    if (typeof Proxy === "function") return true;

    try {
      Date.prototype.toString.call(Reflect.construct(Date, [], function () {}));
      return true;
    } catch (e) {
      return false;
    }
  }

  return function () {
    var Super = _getPrototypeOf(Derived),
        result;

    if (isNativeReflectConstruct()) {
      var NewTarget = _getPrototypeOf(this).constructor;

      result = Reflect.construct(Super, arguments, NewTarget);
    } else {
      result = Super.apply(this, arguments);
    }

    return _possibleConstructorReturn(this, result);
  };
}

import React from 'react';
import classNames from 'classnames';
import { isEmptyFile } from '../../utils/validate';
import { withField, FieldLabel } from '../Field';
/**
 * File attachment field and label that applies state-template styling
 *
 * Extends [HTMLInputElement](https://developer.mozilla.org/en-US/docs/Web/API/HTMLInputElement) properties (id, data-*, etc)
 */

export var FieldFile =
/*#__PURE__*/
function (_React$PureComponent) {
  _inherits(FieldFile, _React$PureComponent);

  var _super = _createSuper(FieldFile);

  function FieldFile(props, context) {
    var _this;

    _classCallCheck(this, FieldFile);

    _this = _super.call(this, props, context);

    _this.eventHandler = function (func) {
      return function () {
        var multiple = _this.props.multiple;
        var files = _this.inputRef.current.files;
        var value = multiple ? files : files[0];
        return func(value || null);
      };
    };

    _this.getFileText = function () {
      var placeholder = _this.props.placeholder;
      var current = _this.inputRef.current;

      if (current) {
        var files = current.files; // multiple files

        if (files && files.length > 1) {
          return "".concat(files.length, " files");
        } // single file


        if (files[0]) {
          return files[0].name;
        }
      } // no file


      return placeholder || 'No File Selected';
    };

    _this.inputRef = props.inputRef || React.createRef();
    return _this;
  }

  _createClass(FieldFile, [{
    key: "componentDidUpdate",
    value: function componentDidUpdate() {
      var value = this.props.value; // handle resetting the form

      if (!value) {
        this.inputRef.current.value = '';
      }
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props = this.props,
          ariaDescribedBy = _this$props['aria-describedby'],
          btnText = _this$props.btnText,
          className = _this$props.className,
          inputRef = _this$props.inputRef,
          label = _this$props.label,
          name = _this$props.name,
          onBlur = _this$props.onBlur,
          onChange = _this$props.onChange,
          onFocus = _this$props.onFocus,
          required = _this$props.required,
          tooltip = _this$props.tooltip,
          value = _this$props.value,
          rest = _objectWithoutProperties(_this$props, ["aria-describedby", "btnText", "className", "inputRef", "label", "name", "onBlur", "onChange", "onFocus", "required", "tooltip", "value"]);

      var cn = classNames(['field__file', className]);
      var fileNameId = "".concat(name, "--filename");
      var fileNameText = this.getFileText();
      var describedBy = ariaDescribedBy ? "".concat(ariaDescribedBy, " ").concat(fileNameId) : fileNameId;
      return (
        /*#__PURE__*/
        React.createElement(React.Fragment, null,
        /*#__PURE__*/
        React.createElement(FieldLabel, {
          label: label,
          name: name,
          required: required,
          tooltip: tooltip,
          tag: 'div'
        }),
        /*#__PURE__*/
        React.createElement("div", {
          "data-test": 'field__file',
          className: cn
        },
        /*#__PURE__*/
        React.createElement("input", Object.assign({
          "aria-describedby": describedBy,
          "aria-label": label,
          type: 'file',
          onChange: this.eventHandler(onChange),
          onBlur: this.eventHandler(onBlur),
          onFocus: this.eventHandler(onFocus),
          files: value,
          ref: this.inputRef
        }, rest)),
        /*#__PURE__*/
        React.createElement("label", {
          className: 'form-control field__file-text',
          htmlFor: name,
          "aria-hidden": true
        }, fileNameText),
        /*#__PURE__*/
        React.createElement("span", {
          id: fileNameId,
          hidden: true
        }, fileNameText),
        /*#__PURE__*/
        React.createElement("div", {
          className: 'field__file-button'
        }, btnText)))
      );
    }
  }]);

  return FieldFile;
}(React.PureComponent);
FieldFile.defaultProps = {
  'aria-describedby': null,
  'aria-invalid': 'false',
  accept: null,
  btnText: 'Choose File',
  capture: null,
  className: null,
  disabled: false,
  id: null,
  inputRef: null,
  multiple: false,
  onBlur: null,
  onChange: null,
  onFocus: null,
  placeholder: null,
  required: false,
  tooltip: null,
  value: null
};
export default withField(isEmptyFile)(FieldFile);