import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
import React from 'react';
import classNames from 'classnames';
import { isEmptyText } from '../../utils/validate';
import { withField, FieldLabel } from '../Field';
/**
 * Input field and label that applies state-template styling
 *
 * Extends [HTMLInputElement](https://developer.mozilla.org/en-US/docs/Web/API/HTMLInputElement) properties (id, data-*, etc)
 */

export var FieldInput = function FieldInput(props) {
  var className = props.className,
      inputRef = props.inputRef,
      label = props.label,
      name = props.name,
      required = props.required,
      Tag = props.tag,
      tooltip = props.tooltip,
      rest = _objectWithoutProperties(props, ["className", "inputRef", "label", "name", "required", "tag", "tooltip"]);

  var cn = classNames(['field__input', 'form-control', className]);
  return (
    /*#__PURE__*/
    React.createElement(React.Fragment, null,
    /*#__PURE__*/
    React.createElement(FieldLabel, {
      htmlFor: name,
      label: label,
      name: name,
      required: required,
      tooltip: tooltip
    }),
    /*#__PURE__*/
    React.createElement(Tag, Object.assign({
      className: cn,
      "data-test": 'field__input',
      name: name,
      ref: inputRef
    }, rest)))
  );
};
FieldInput.defaultProps = {
  className: null,
  inputRef: null,
  required: false,
  tag: 'input',
  tooltip: null
};
export default withField(isEmptyText)(FieldInput);