import React from 'react';
import classNames from 'classnames';
import * as propUtils from '../../utils/propTypes'; // individual radio button, applies state-template styling

var RadioButton = function RadioButton(props) {
  var ariaDescribedby = props['aria-describedby'],
      ariaInvalid = props['aria-invalid'],
      disabled = props.disabled,
      inline = props.inline,
      name = props.name,
      onBlur = props.onBlur,
      onChange = props.onChange,
      onFocus = props.onFocus,
      option = props.option,
      value = props.value,
      variant = props.variant;
  var id = !option.key ? "".concat(name, "-").concat(option.value) : option.key;
  var inputProps = {
    'aria-describedby': ariaDescribedby,
    'aria-invalid': ariaInvalid,
    checked: value === option.value,
    disabled: disabled,
    id: id,
    name: name,
    type: 'radio'
  };

  if (onBlur) {
    inputProps.onBlur = function () {
      return onBlur(option.value);
    };
  }

  if (onChange) {
    inputProps.onChange = function () {
      return onChange(option.value);
    };
  }

  if (onFocus) {
    inputProps.onFocus = function () {
      return onFocus(option.value);
    };
  }

  var cn = classNames(['check', option.className]);

  if (variant) {
    return (
      /*#__PURE__*/
      React.createElement("label", {
        "data-test": 'field__radio-button',
        className: cn,
        htmlFor: id
      },
      /*#__PURE__*/
      React.createElement("input", Object.assign({
        className: 'hidden-up pos-abs top-0 left-0'
      }, inputProps)),
      /*#__PURE__*/
      React.createElement("span", {
        className: "btn btn-lg btn-block bg-".concat(variant, "--checked rounded-0")
      },
      /*#__PURE__*/
      React.createElement("div", null, option.label)))
    );
  }

  cn = classNames(['p-l-md m-l-0 m-r-md', option.className, inline ? 'form-check-inline' : 'form-check']);
  return (
    /*#__PURE__*/
    React.createElement("label", {
      "data-test": 'field__radio-button',
      className: cn,
      htmlFor: id
    },
    /*#__PURE__*/
    React.createElement("input", Object.assign({
      id: id,
      className: 'hidden-up pos-abs'
    }, inputProps)),
    /*#__PURE__*/
    React.createElement("div", {
      className: 'check-icon-radio',
      "aria-hidden": true
    },
    /*#__PURE__*/
    React.createElement("i", null)),
    /*#__PURE__*/
    React.createElement("div", null, option.label))
  );
};

RadioButton.defaultProps = {
  'aria-describedby': null,
  'aria-invalid': 'false',
  disabled: false,
  inline: false,
  onBlur: null,
  onChange: null,
  onFocus: null,
  variant: null
};
export default RadioButton;