import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
import _objectSpread from "@babel/runtime/helpers/esm/objectSpread2";
import React from 'react';
import Select, { components as Components } from 'react-select';
import { withField, FieldLabel } from '../Field';
import { isEmptyOrNull } from '../../utils/validate';
var standardStyling = {
  option: function option(styles) {
    return _objectSpread(_objectSpread({}, styles), {}, {
      borderColor: 'gray'
    });
  },
  control: function control(styles, state) {
    return _objectSpread(_objectSpread({}, styles), {}, {
      webkitAppearance: 'none',
      backgroundColor: state.isDisabled ? '#e9ecef' : 'white',
      borderColor: '#ccc',
      borderRadius: '0px',
      '&:focus-within': {
        borderColor: '#80bdff',
        outline: '0',
        boxShadow: '0 0 0 0.2rem rgba(0,123,255,.25)'
      },
      lineHeight: '1'
    });
  },
  menu: function menu(styles) {
    return _objectSpread(_objectSpread({}, styles), {}, {
      menuPosition: 'relative'
    });
  },
  singleValue: function singleValue(styles) {
    return _objectSpread(_objectSpread({}, styles), {}, {
      color: '#495057'
    });
  }
};

var standardTheme = function standardTheme(theme) {
  return _objectSpread(_objectSpread({}, theme), {}, {
    colors: _objectSpread(_objectSpread({}, theme.colors), {}, {
      danger: 'black',
      dangerLight: 'red'
    })
  });
};

export var FieldReactSelect = function FieldReactSelect(_ref) {
  var inputRef = _ref.inputRef,
      label = _ref.label,
      name = _ref.name,
      required = _ref.required,
      tooltip = _ref.tooltip,
      components = _ref.components,
      styles = _ref.styles,
      theme = _ref.theme,
      _onBlur = _ref.onBlur,
      renderTarget = _ref.renderTarget,
      rest = _objectWithoutProperties(_ref, ["inputRef", "label", "name", "required", "tooltip", "components", "styles", "theme", "onBlur", "renderTarget"]);

  var indicatorSeparatorStyle = {
    alignSelf: 'stretch',
    backgroundColor: 'lightgray',
    width: 1
  };

  var CaretDownIcon = function CaretDownIcon() {
    return (
      /*#__PURE__*/
      React.createElement("div", {
        className: 'ca-gov-icon-triangle-down'
      })
    );
  };

  var DropdownIndicator = function DropdownIndicator(props) {
    return (
      /*#__PURE__*/
      React.createElement(Components.DropdownIndicator, props,
      /*#__PURE__*/
      React.createElement(CaretDownIcon, null))
    );
  }; // innerProps is of type Any - disabling prop types
  // eslint-disable-next-line react/prop-types, max-len


  var IndicatorSeparator = function IndicatorSeparator(_ref2) {
    var innerProps = _ref2.innerProps;
    return (
      /*#__PURE__*/
      React.createElement("span", Object.assign({
        style: indicatorSeparatorStyle
      }, innerProps))
    );
  };

  var selectProps = _objectSpread({
    inputRef: inputRef,
    label: label,
    name: name,
    required: required,
    tooltip: tooltip,
    styles: styles || standardStyling,
    theme: theme || standardTheme,
    components: components || {
      IndicatorSeparator: IndicatorSeparator,
      DropdownIndicator: DropdownIndicator
    },
    renderTarget: renderTarget
  }, rest);

  var renderInDOM;

  if (renderTarget === 'default') {
    renderInDOM = null;
  } else if (renderTarget) {
    renderInDOM = document.querySelector(renderTarget);
  } else {
    renderInDOM = document.querySelector('body');
  }

  return (
    /*#__PURE__*/
    React.createElement(React.Fragment, null,
    /*#__PURE__*/
    React.createElement(FieldLabel, {
      htmlFor: name,
      label: label,
      name: name,
      required: required,
      tooltip: tooltip
    }),
    /*#__PURE__*/
    React.createElement(Select, Object.assign({}, selectProps, {
      ref: inputRef,
      menuPortalTarget: renderInDOM,
      onBlur: function onBlur() {
        return _onBlur && _onBlur();
      }
    })))
  );
};
FieldReactSelect.defaultProps = {
  components: null,
  inputRef: null,
  onBlur: null,
  required: false,
  styles: null,
  theme: null,
  tooltip: null,
  renderTarget: null
};
export default withField(isEmptyOrNull)(FieldReactSelect);