### React Select Basic Multi Select
```jsx
import { FieldReactSelect } from 'state-template';

const options = [
  { value: 'chocolate', label: 'Chocolate' },
  { value: 'strawberry', label: 'Strawberry' },
  { value: 'vanilla', label: 'Vanilla' }
]

// example `ref`, access using inputRef.current
const inputRef = React.createRef();
<ExampleForm form={'reactSelect'}>

  <FieldReactSelect
    name={'Flavor'}
    isMulti
    options={options}
    placeholder={'Select Yo Flavor!'}
    label={'React Select Label'}
  />

</ExampleForm>
```

### Required React Select with CustomStyling

```jsx
import { FieldReactSelect } from 'state-template';

const options = [
  { value: 'chocolate', label: 'Chocolate' },
  { value: 'strawberry', label: 'Strawberry' },
  { value: 'vanilla', label: 'Vanilla' }
]


const customStyles = {
  option: (styles, state) => ({
    ...styles,
    color: state.isSelected ? '#ff4c00' : 'blue',
    backgroundColor: state.isSelected ? 'black' : 'white'
  }),
  control: (styles, state) => ({
    ...styles,
    width: 200
  }),

  menu: (styles, state) => ({
    ...styles,
    menuPosition: 'relative',
  }),
  singleValue: (styles, state) => ({
    ...styles,
  }),
};

<ExampleForm form={'reactSelect1'}>

  <FieldReactSelect
    name={'Flavor'}
    required
    options={options}
    styles={customStyles}
    placeholder={'Select Yo Flavor!'}
    label={'React Select Label'}
  />

</ExampleForm>
```
### React Select CustomThemeing

```jsx
import { FieldReactSelect } from 'state-template';

const options = [
  { value: 'chocolate', label: 'Chocolate' },
  { value: 'strawberry', label: 'Strawberry' },
  { value: 'vanilla', label: 'Vanilla' }
]

const customTheme = (theme) => ({
  ...theme,
  colors: {
    ...theme.colors,
    danger: 'black',
    dangerLight: 'red',
    primary25: 'hotpink',
    primary: 'black',

    // All possible overrides
    // primary: '#2684FF',
    // primary75: '#4C9AFF',
    // primary50: '#B2D4FF',
    // primary25: '#DEEBFF',

    // danger: '#DE350B',
    // dangerLight: '#FFBDAD',

    // neutral0: 'hsl(0, 0%, 100%)',
    // neutral5: 'hsl(0, 0%, 95%)',
    // neutral10: 'hsl(0, 0%, 90%)',
    // neutral20: 'hsl(0, 0%, 80%)',
    // neutral30: 'hsl(0, 0%, 70%)',
    // neutral40: 'hsl(0, 0%, 60%)',
    // neutral50: 'hsl(0, 0%, 50%)',
    // neutral60: 'hsl(0, 0%, 40%)',
    // neutral70: 'hsl(0, 0%, 30%)',
    // neutral80: 'hsl(0, 0%, 20%)',
    // neutral90: 'hsl(0, 0%, 10%)',
  },
  // Other options you can use
  // borderRadius: 4,
  // baseUnit: 4,
  // controlHeight: 38
  // menuGutter: baseUnit * 2
});

<ExampleForm form={'reactSelect2'}>

  <FieldReactSelect
    name={'Flavor'}
    isMulti
    options={options}
    placeholder={'Select Yo Flavor!'}
    label={'React Select Label'}
    theme={customTheme}
    isClearable={false}
  />

</ExampleForm>
```