import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
import React from 'react';
import classNames from 'classnames';
import { isEmptyRadio } from '../../utils/validate';
import * as propUtils from '../../utils/propTypes';
import { withField, FieldLabel } from '../Field';
/**
 * Select field and label that applies state-template styling
 *
 * Extends [HTMLSelectElement](https://developer.mozilla.org/en-US/docs/Web/API/HTMLSelectElement) properties (id, data-*, etc)
 */

export var FieldSelect = function FieldSelect(props) {
  var className = props.className,
      placeholder = props.placeholder,
      inputRef = props.inputRef,
      label = props.label,
      multiple = props.multiple,
      name = props.name,
      options = props.options,
      required = props.required,
      tooltip = props.tooltip,
      value = props.value,
      rest = _objectWithoutProperties(props, ["className", "placeholder", "inputRef", "label", "multiple", "name", "options", "required", "tooltip", "value"]); // expects array as default if multiple is used


  var mappedValue = multiple && !value ? [] : value;
  var cn = classNames(['select', 'field__select', {
    multiple: multiple
  }, className]);
  return (
    /*#__PURE__*/
    React.createElement(React.Fragment, null,
    /*#__PURE__*/
    React.createElement(FieldLabel, {
      htmlFor: name,
      label: label,
      name: name,
      required: required,
      tooltip: tooltip
    }),
    /*#__PURE__*/
    React.createElement("div", {
      "data-test": 'field__select',
      className: cn
    },
    /*#__PURE__*/
    React.createElement("select", Object.assign({
      multiple: multiple,
      value: mappedValue,
      className: 'form-control',
      ref: inputRef
    }, rest), !placeholder ?
    /*#__PURE__*/
    React.createElement("option", {
      disabled: true,
      hidden: true,
      value: ''
    }, null) :
    /*#__PURE__*/
    React.createElement("option", {
      value: ''
    }, placeholder), options.filter(function (x) {
      return !x.hidden;
    }).map(function (option) {
      return (
        /*#__PURE__*/
        React.createElement("option", {
          key: !option.key ? option.value : option.key,
          value: option.value
        }, option.label)
      );
    }))))
  );
};
FieldSelect.defaultProps = {
  'aria-invalid': 'false',
  className: null,
  inputRef: null,
  required: false,
  multiple: false,
  tooltip: null,
  value: null,
  placeholder: null
};
export default withField(isEmptyRadio)(FieldSelect);