import _classCallCheck from "@babel/runtime/helpers/esm/classCallCheck";
import _createClass from "@babel/runtime/helpers/esm/createClass";
import _inherits from "@babel/runtime/helpers/esm/inherits";
import _possibleConstructorReturn from "@babel/runtime/helpers/esm/possibleConstructorReturn";
import _getPrototypeOf from "@babel/runtime/helpers/esm/getPrototypeOf";

function _createSuper(Derived) {
  function isNativeReflectConstruct() {
    if (typeof Reflect === "undefined" || !Reflect.construct) return false;
    if (Reflect.construct.sham) return false;
    if (typeof Proxy === "function") return true;

    try {
      Date.prototype.toString.call(Reflect.construct(Date, [], function () {}));
      return true;
    } catch (e) {
      return false;
    }
  }

  return function () {
    var Super = _getPrototypeOf(Derived),
        result;

    if (isNativeReflectConstruct()) {
      var NewTarget = _getPrototypeOf(this).constructor;

      result = Reflect.construct(Super, arguments, NewTarget);
    } else {
      result = Super.apply(this, arguments);
    }

    return _possibleConstructorReturn(this, result);
  };
}

import React from 'react';
import classNames from 'classnames';
import debounce from 'lodash.debounce';
import * as propUtils from '../../utils/propTypes';
import Overlay from '../Overlay';
import Branding from './Branding';
import MobileControls from './MobileControls';
import Navigation from './Navigation';
import Search from './Search';
import SettingsBar from './SettingsBar';
import UtilityHeader from './UtilityHeader';
/**
 * Renders a header that handles responsive viewports,
 * compacting on scroll, opening settings, and
 * generating navigation.
 */

var Header =
/*#__PURE__*/
function (_React$Component) {
  _inherits(Header, _React$Component);

  var _super = _createSuper(Header);

  function Header(props) {
    var _this;

    _classCallCheck(this, Header);

    _this = _super.call(this, props);

    _this.setSettings = function () {
      document.body.style.zoom = Number(localStorage.getItem('zoom'));

      if (localStorage.getItem('highContrast')) {
        document.getElementsByTagName('html')[0].classList.add('high-contrast');
      }
    };

    _this.onScroll = function () {
      var isCompact = _this.state.isCompact;
      var newIsCompact = window.scrollY > 130;

      if (isCompact !== newIsCompact) {
        _this.setState({
          isCompact: newIsCompact
        });
      }
    };

    _this.toggleMobileOpen = function () {
      var isMobileOpen = _this.state.isMobileOpen;

      _this.setState({
        isMobileOpen: !isMobileOpen
      });
    };

    _this.toggleSettingsOpen = function () {
      var isSettingsOpen = _this.state.isSettingsOpen;

      _this.setState({
        isSettingsOpen: !isSettingsOpen
      });
    };

    _this.state = {
      isCompact: false,
      isMobileOpen: false,
      isSettingsOpen: false
    };
    _this.scrollEvent = debounce(_this.onScroll, 200);
    return _this;
  }

  _createClass(Header, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      window.addEventListener('scroll', this.scrollEvent);
      this.setSettings();
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      window.removeEventListener('scroll', this.scrollEvent);
    } // set setttings user has set (in SettingsBar)

  }, {
    key: "render",
    value: function render() {
      var _this$props = this.props,
          fixed = _this$props.fixed,
          align = _this$props.align,
          brandingLogo = _this$props.brandingLogo,
          routes = _this$props.routes,
          contactLink = _this$props.contactLink,
          title = _this$props.title;
      var _this$state = this.state,
          isCompact = _this$state.isCompact,
          isMobileOpen = _this$state.isMobileOpen,
          isSettingsOpen = _this$state.isSettingsOpen;
      var filteredRoutes = routes.filter(function (x) {
        return !x.hidden;
      });
      var cn = classNames(['global-header', {
        fixed: fixed
      }, {
        compact: isCompact
      }, align]);
      return (
        /*#__PURE__*/
        React.createElement(React.Fragment, null,
        /*#__PURE__*/
        React.createElement("header", {
          role: 'banner',
          className: cn,
          "data-test": 'header'
        },
        /*#__PURE__*/
        React.createElement(UtilityHeader, {
          toggleSettingsOpen: this.toggleSettingsOpen,
          contactLink: contactLink,
          title: title
        }),
        /*#__PURE__*/
        React.createElement(SettingsBar, {
          toggleSettingsOpen: this.toggleSettingsOpen,
          isSettingsOpen: isSettingsOpen
        }),
        /*#__PURE__*/
        React.createElement(Branding, brandingLogo),
        /*#__PURE__*/
        React.createElement(MobileControls, {
          toggleMobileOpen: this.toggleMobileOpen,
          routes: filteredRoutes
        }),
        /*#__PURE__*/
        React.createElement("div", {
          className: 'navigation-search'
        },
        /*#__PURE__*/
        React.createElement(Navigation, {
          isMobileOpen: isMobileOpen,
          toggleMobileOpen: this.toggleMobileOpen,
          routes: filteredRoutes
        }),
        /*#__PURE__*/
        React.createElement("div", {
          id: 'head-search',
          className: 'search-container'
        },
        /*#__PURE__*/
        React.createElement(Search, null))),
        /*#__PURE__*/
        React.createElement("div", {
          className: 'header-decoration'
        })),
        /*#__PURE__*/
        React.createElement(Overlay, {
          isMobile: true,
          show: isMobileOpen,
          onClick: this.toggleMobileOpen,
          className: 'header-overlay'
        }))
      );
    }
  }]);

  return Header;
}(React.Component);

Header.defaultProps = {
  fixed: true,
  align: 'center',
  brandingLogo: propUtils.brandingLogoDefault,
  contactLink: propUtils.contactLinkDefault,
  title: null,
  routes: []
};
export default Header;