
### Fully Managed Header

```jsx
const Home = () => <div>in Home</div>;
const Help = () => <div>in Help</div>;

const routes = [
  {
    key: 'home',
    name: 'Home',
    path: '/',
    exact: true,
    icon: 'ca-gov-icon-home',
    component: Home,
  },
  {
    key: 'help',
    name: 'Help',
    path: '/help',
    exact: true,
    icon: 'ca-gov-icon-question-line',
    component: Help,
  },
];

<div style={{ overflow: 'auto', display: 'grid' }}>
  <Header 
    fixed={false} 
    routes={routes} 
  />
</div>
```
### Fully Managed Header
#### Alignment, Title, Contact Link

```jsx
const Home = () => <div>in Home</div>;
const Help = () => <div>in Help</div>;

const routes = [
  {
    key: 'home',
    name: 'Home',
    path: '/',
    exact: true,
    icon: 'ca-gov-icon-home',
    component: Home,
  },
  {
    key: 'help',
    name: 'Help',
    path: '/help',
    exact: true,
    icon: 'ca-gov-icon-question-line',
    component: Help,
  },
];

const contactLink = {
  text: 'HELP!',
  href: 'https://cdt.ca.gov/support/',
};

<div style={{ overflow: 'auto', display: 'grid' }}>
  <Header 
    fixed={false} 
    align={'right'}
    contactLink={contactLink}
    title={'Custom Title'}
    routes={routes} 
  />
</div>
```
### Unmanaged Header

```jsx
import { Navigation, MobileControls, Branding, SettingsBar, UtilityHeader, A } from 'state-template';

class ExampleUnmanagedHeader extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      isSettingsOpen: false,
      isMobileOpen: false,
		 };
    this.toggleSettingsOpen = this.toggleSettingsOpen.bind(this);
    this.toggleMobileOpen = this.toggleMobileOpen.bind(this);
  }

  // use arrow syntax here instead of binding above...
  // limitation of styleguidist transpiler..
  toggleSettingsOpen() {
    const { isSettingsOpen } = this.state;
    this.setState({ isSettingsOpen: !isSettingsOpen });
  }

  // use arrow syntax here instead of binding above...
  // limitation of styleguidist transpiler..
  toggleMobileOpen() {
    const { isMobileOpen } = this.state;
    this.setState({ isMobileOpen: !isMobileOpen });
  }

  render() {
    const {
      isMobileOpen, toggleSettingsOpen, toggleMobileOpen, isSettingsOpen,
    } = this.state;
    const title = 'Unmanaged Header';
    const Home = () => <div>in Home</div>;
    const Help = () => <div>in Help</div>;
    const routes = [
      {
        key: 'home',
        name: 'Home',
        path: '/',
        exact: true,
        icon: 'ca-gov-icon-home',
        component: Home,
      },
      {
        key: 'help',
        name: 'Help',
        path: '/help',
        exact: true,
        icon: 'ca-gov-icon-question-line',
        component: Help,
      },
    ];
    const brandingProps = {
      src: odiLogo,
      alt: 'Office of Digital Innovation logo',
      href: 'https://cdt.ca.gov/',
    };
    const contactLink = {
      text: 'HELP!',
      href: 'https://cdt.ca.gov/support/',
    };
    const settingsChildren = <A href={'/'} text={'Custom Button!'} />;
    return (
    // must be wrapped in className={'global-header'}
      <header className={'global-header right'}>
        <UtilityHeader
          settingsChildren={settingsChildren}
          toggleSettingsOpen={this.toggleSettingsOpen}
          contactLink={contactLink}
          title={title}
        />
        <SettingsBar
          toggleSettingsOpen={this.toggleSettingsOpen}
          isSettingsOpen={isSettingsOpen}
        />
        <Branding {...brandingProps} />
        <div className={'navigation-search'}>
          <MobileControls
            routes={routes}
            toggleMobileOpen={this.toggleMobileOpen}
          />
          <Navigation
            isMobileOpen={isMobileOpen}
            toggleMobileOpen={this.toggleMobileOpen}
            routes={routes}
					/>
        </div>
      </header>
    );
  }
}

<ExampleUnmanagedHeader />;

```
### Settings Bar Used with UtilityHeader

```jsx
import { SettingsBar, UtilityHeader } from 'state-template';

class ExapmleUtilityHeader extends React.Component {
  constructor(props) {
    super(props);
    this.state = { isSettingsOpen: false };
    this.toggleSettingsOpen = this.toggleSettingsOpen.bind(this);
  }

  // use arrow syntax here instead of binding above...
  // limitation of styleguidist transpiler..
  toggleSettingsOpen() {
    const { isSettingsOpen } = this.state;
    this.setState({ isSettingsOpen: !isSettingsOpen });
  }

  render() {
    const { toggleSettingsOpen, isSettingsOpen } = this.state;
    const title = 'Utility Header';
    const contactLink = {
      text: 'HELP!',
      href: 'https://cdt.ca.gov/support/',
    };

    return (
      <>
        <UtilityHeader
          toggleSettingsOpen={this.toggleSettingsOpen}
          contactLink={contactLink}
          title={title}
        />
        <SettingsBar
          toggleSettingsOpen={this.toggleSettingsOpen}
          isSettingsOpen={isSettingsOpen}
        />
      </>
    );
  }
}

<ExapmleUtilityHeader />;

```
### Routing Portion of Header

`<Branding >` is used for the home link and logo

`<MobileControls />` is the button in the header that appears on mobile

`<Navigation />` is the Navigation links that appear in the header on desktop and below the header on mobile

```jsx
import { Navigation, MobileControls, Branding } from 'state-template';

class ExapmleRoutingMenu extends React.Component {
  constructor(props) {
    super(props);
    this.state = { isMobileOpen: false };
    this.toggleMobileOpen = this.toggleMobileOpen.bind(this);
  }

  // use arrow syntax here instead of binding above...
  // limitation of styleguidist transpiler..
  toggleMobileOpen() {
    const { isMobileOpen } = this.state;
    this.setState({ isMobileOpen: !isMobileOpen });
  }

  render() {
    const { isMobileOpen } = this.state;
    const title = 'Settings';
    const Home = () => <div>in Home</div>;
    const Help = () => <div>in Help</div>;
    const routes = [
      {
        key: 'home',
        name: 'Home',
        path: '/',
        exact: true,
        icon: 'ca-gov-icon-home',
        component: Home,
      },
      {
        key: 'help',
        name: 'Help',
        path: '/help',
        exact: true,
        icon: 'ca-gov-icon-question-line',
        component: Help,
      },
    ];
    const brandingProps = {
      src: odiLogo,
      alt: 'Office of Digital Innovation logo',
      href: 'https://cdt.ca.gov/',
    };

    return (
    // must be wrapped in className={'global-header'}
      <div className={'global-header right'}>
        <Branding {...brandingProps} />

        <MobileControls
          routes={routes}
          toggleMobileOpen={this.toggleMobileOpen}
        />
        <Navigation
          isMobileOpen={isMobileOpen}
          toggleMobileOpen={this.toggleMobileOpen}
          routes={routes}
        />
      </div>
    );
  }
}

<ExapmleRoutingMenu />;
```

### SettingsBar by itself

```jsx
import { Button, SettingsBar } from 'state-template';

class ExapmleSearchBar extends React.Component {
  constructor(props) {
    super(props);
    this.state = { isSettingsOpen: false };
    this.toggleSettingsOpen = this.toggleSettingsOpen.bind(this);
  }

  // use arrow syntax here instead of binding above...
  // limitation of styleguidist transpiler..
  toggleSettingsOpen() {
    const { isSettingsOpen } = this.state;
    this.setState({ isSettingsOpen: !isSettingsOpen });
  }

  render() {
    const { toggleSettingsOpen, isSettingsOpen } = this.state;
    const title = 'Settings';

    return (
      <>
        <Button
          variant={'primary'}
          onClick={this.toggleSettingsOpen}
          text={title}
        />
        <SettingsBar
          toggleSettingsOpen={this.toggleSettingsOpen}
          isSettingsOpen={isSettingsOpen}
        />
      </>
    );
  }
}

<ExapmleSearchBar />;

```




