import React from 'react';
import { withRouter } from 'react-router-dom';
import A from '../../A';
/**
 * A single navigation item
 * @param {string} to       - path to navigate to
 * @param {array} children  - children to render
 * @param {func} onClick    - fired when item is clicked on
 * @param {string} hash     - current hash name from redux
 */

var NavItem = function NavItem(_ref) {
  var href = _ref.href,
      icon = _ref.icon,
      location = _ref.location,
      name = _ref.name,
      onClick = _ref.onClick,
      path = _ref.path,
      toggleMobileOpen = _ref.toggleMobileOpen;
  var isActive = location.pathname === path;
  var activeClass = isActive ? 'active' : '';

  var mappedOnClick = function mappedOnClick(event) {
    if (onClick) onClick(event);
    toggleMobileOpen(event);
  };

  return (
    /*#__PURE__*/
    React.createElement("li", {
      className: "nav-item ".concat(activeClass)
    },
    /*#__PURE__*/
    React.createElement(A, {
      to: path,
      href: href,
      className: 'first-level-link',
      onClick: mappedOnClick
    },
    /*#__PURE__*/
    React.createElement("span", {
      className: icon,
      "aria-hidden": true
    }), name))
  );
};

NavItem.defaultProps = {
  href: null,
  icon: null,
  onClick: null,
  path: null
};
export default withRouter(NavItem);