import React from 'react';
import { shallow } from 'enzyme';
import { SettingsBar as fromLib } from '../../..';
import SettingsBar from './SettingsBar';
var props = {
  isSettingsOpen: true,
  toggleSettingsOpen: jest.fn()
};
var wrapper;
var instance;
describe('UtilityHeader', function () {
  beforeEach(function () {
    wrapper = shallow(
    /*#__PURE__*/
    React.createElement(SettingsBar, props));
    instance = wrapper.instance();
  });
  it('should be exported as part of the library', function () {
    expect(fromLib).toEqual(SettingsBar);
  });
  it('should render correctly', function () {
    expect(wrapper).toMatchSnapshot();
  });
  it('should reset font size on resetFont', function () {
    instance.resetFont();
    expect(localStorage.getItem('zoom')).toEqual('1');
  });
  it('should increase font size on increaseFont', function () {
    instance.increaseFont();
    expect(localStorage.getItem('zoom')).toEqual('1.1');
  });
  it('should decrease font size on descreaseFont', function () {
    // set to 1
    instance.resetFont(); // decrease by .1

    instance.descreaseFont();
    expect(localStorage.getItem('zoom')).toEqual('0.9');
  });
  it('should set High Contrast on setHighContrast', function () {
    instance.setHighContrast();
    expect(localStorage.getItem('highContrast')).toEqual('on');
  });
  it('should reset High Contrast on clearHighContrast', function () {
    instance.clearHighContrast();
    expect(localStorage.getItem('highContrast')).toBeNull();
  });
  it('should update font size on updateFont if zoom exists', function () {
    document.body.style.zoom = 1;
    instance.updateFont({
      amount: 1
    });
    expect(localStorage.getItem('zoom')).toEqual('2');
  });
  it('should update font size on updateFont and set zoom if not already set', function () {
    document.body.style.zoom = null;
    instance.updateFont({
      amount: 1
    });
    expect(localStorage.getItem('zoom')).toEqual('2');
  });
  it('should be hidden if isSettingsOpen is false', function () {
    props.isSettingsOpen = false;
    wrapper = shallow(
    /*#__PURE__*/
    React.createElement(SettingsBar, props));
    expect(wrapper.find('.site-settings').hasClass('show')).toBe(false);
  });
});