import _regeneratorRuntime from "@babel/runtime/regenerator";
import _objectSpread from "@babel/runtime/helpers/esm/objectSpread2";
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import * as auth from './auth';
export var wait = function wait(ms) {
  return new Promise(function (r) {
    return setTimeout(r, ms);
  });
};
/**
 * Checks if a network request came back fine, and throws an error if not
 * @param  {object} response   A response from a network request
 * @return {object|undefined} Returns either the response, or throws an error
 */

export function checkStatus(_x) {
  return _checkStatus.apply(this, arguments);
}
/**
 * Parses the JSON returned by a network request
 * @param  {object} response A response from a network request
 * @return {object}          The parsed JSON from the request
 */

function _checkStatus() {
  _checkStatus = _asyncToGenerator(
  /*#__PURE__*/
  _regeneratorRuntime.mark(function _callee(response) {
    var contentType, errorResponse, errorMessage, _errorMessage;

    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            if (!(response.status >= 200 && response.status < 300)) {
              _context.next = 2;
              break;
            }

            return _context.abrupt("return", response);

          case 2:
            contentType = response.headers.get('content-type');
            errorResponse = response;

            if (!contentType) {
              _context.next = 17;
              break;
            }

            if (!contentType.match('application/json')) {
              _context.next = 12;
              break;
            }

            _context.next = 8;
            return response.json();

          case 8:
            errorMessage = _context.sent;
            errorResponse.errorMessage = errorMessage;
            _context.next = 17;
            break;

          case 12:
            if (!contentType.match('text/plain')) {
              _context.next = 17;
              break;
            }

            _context.next = 15;
            return response.text();

          case 15:
            _errorMessage = _context.sent;
            errorResponse.errorMessage = _errorMessage;

          case 17:
            throw errorResponse;

          case 18:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  }));
  return _checkStatus.apply(this, arguments);
}

export function parseJSON(response) {
  var contentType = response.headers.get('content-type');

  if (contentType && contentType.match('application/json')) {
    return response.json();
  }

  var contentDisposition = response.headers.get('Content-Disposition');

  if (contentDisposition && contentDisposition.match(/filename=/)) {
    return response.blob().then(function (x) {
      x.name = contentDisposition.match(/filename=([^;]*)/)[1]; // eslint-disable-line

      return x;
    });
  }

  return null;
}
/**
 * Requests a URL, returning a promise
 * @param  {string} url       The URL we want to request
 * @param  {object} [options] The options we want to pass to "fetch"
 * @return {object}           The response data
 */

export function request(url) {
  var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

  // config settings to send api
  var newOptions = _objectSpread(_objectSpread({}, options), {}, {
    headers: _objectSpread({}, options.headers || {
      'Content-Type': 'application/json',
      'Access-Control-Expose-Headers': 'Content-Disposition'
    })
  });

  return fetch(url, newOptions).then(checkStatus).then(parseJSON);
}
/**
 * Requests a URL with jwt token in header for authorization, returning a promise
 * Waits until jwt token is set in localStorage before making call
 * @param  {string} url       The URL we want to request
 * @param  {object} [options] The options we want to pass to "fetch"
 * @return {object}           The response data
 */

export function requestWithToken(url) {
  var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  var token = auth.getToken(); // config settings to send api

  var newOptions = _objectSpread(_objectSpread({}, options), {}, {
    headers: _objectSpread({
      Authorization: "Bearer ".concat(token)
    }, options.headers || {
      'Content-Type': 'application/json'
    })
  });

  return fetch(url, newOptions).then(checkStatus).then(parseJSON);
}
export var shouldFetch = function shouldFetch(lastFetched) {
  var cacheTime = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 300000;
  var date = new Date(lastFetched); // invalid date, fetch...

  if (!lastFetched || Number.isNaN(date)) {
    return true;
  } // check if set amount of time has passed


  return Date.now() > lastFetched + cacheTime;
};