import _regeneratorRuntime from "@babel/runtime/regenerator";
import _objectSpread from "@babel/runtime/helpers/esm/objectSpread2";

var _marked =
/*#__PURE__*/
_regeneratorRuntime.mark(authenticate);

import { call } from 'redux-saga/effects';
import decode from 'jwt-decode';
export var TOKEN = 'id_token';
export var DEFAULT_EXPIRE = 1000;
/**
 * Sets a token for authenication in localStorage
 * @param {String} token  - token to set
 */

export function setToken(token) {
  localStorage.setItem(TOKEN, token);
}
/**
 * Gets the authenication token from localStorage
 * @return {String}     - authenication token
 */

export function getToken() {
  return localStorage.getItem(TOKEN);
}
/**
 * Clears the authenication token from localStorage
 */

export function clearToken() {
  localStorage.removeItem(TOKEN);
}
/**
 * Helper function to valdate that token exists and is not expired
 * @param {object} token  - jwt toke
 * @return {bool}         - valid ? true : false
 */

export function validToken(token) {
  try {
    var _decode = decode(token),
        exp = _decode.exp;

    var now = Date.now() / 1000;
    return Number(exp) > now;
  } catch (e) {
    return false;
  }
}
/**
 * Decode the token in local storage
 */

export function decodeToken() {
  var token = getToken();
  return decode(token);
}
/**
 * Authenticates a user
 * Checks local storage for token first
 * @param {Object} url      - url to call for authentication
 * @param {Object} options  - options to pass to api call (method, headers, etc)
 * @param {string} tokenKey - key in response jwt is stored on
 */

export function authenticate(_ref) {
  var url, _ref$options, options, _ref$tokenKey, tokenKey, token, newOptions, response, contentType, errorResponse, errorMessage, _errorMessage, json;

  return _regeneratorRuntime.wrap(function authenticate$(_context) {
    while (1) {
      switch (_context.prev = _context.next) {
        case 0:
          url = _ref.url, _ref$options = _ref.options, options = _ref$options === void 0 ? {} : _ref$options, _ref$tokenKey = _ref.tokenKey, tokenKey = _ref$tokenKey === void 0 ? 'id_token' : _ref$tokenKey;
          token = getToken(); // if valid local token use that

          if (!validToken(token)) {
            _context.next = 4;
            break;
          }

          return _context.abrupt("return", decode(token));

        case 4:
          newOptions = _objectSpread(_objectSpread({
            method: 'get'
          }, options), {}, {
            headers: _objectSpread({}, options.headers || {
              'Content-Type': 'application/json'
            })
          });
          _context.next = 7;
          return call(fetch, url, newOptions);

        case 7:
          response = _context.sent;

          if (!(response.status == 400)) {
            _context.next = 25;
            break;
          }

          contentType = response.headers.get('content-type');
          errorResponse = response;

          if (!contentType) {
            _context.next = 24;
            break;
          }

          if (!contentType.match('application/json')) {
            _context.next = 19;
            break;
          }

          _context.next = 15;
          return response.json();

        case 15:
          errorMessage = _context.sent;
          errorResponse.errorMessage = errorMessage;
          _context.next = 24;
          break;

        case 19:
          if (!contentType.match('text/plain')) {
            _context.next = 24;
            break;
          }

          _context.next = 22;
          return response.text();

        case 22:
          _errorMessage = _context.sent;
          errorResponse.errorMessage = _errorMessage;

        case 24:
          throw errorResponse;

        case 25:
          _context.next = 27;
          return response.json();

        case 27:
          json = _context.sent;
          token = json[tokenKey]; // set token into local storage for future authentication caching

          setToken(token);
          return _context.abrupt("return", decode(token));

        case 31:
        case "end":
          return _context.stop();
      }
    }
  }, _marked);
}