import _regeneratorRuntime from "@babel/runtime/regenerator";
import _toConsumableArray from "@babel/runtime/helpers/esm/toConsumableArray";
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import { UserAgentApplication } from 'msal';
import { Client } from '@microsoft/microsoft-graph-client';
var userAgent;
/**
 * Initializes the user agent application
 * @param {string} clientId - Client ID of the registered application in Azure
 * @param {string} redirectUri - Where the user is redirected after login or logout
 * @param {string} authority - Directory you are requesting tokens from
 */

export var initialize = function initialize(clientId, redirectUri, authority) {
  if (!clientId) {
    throw new Error('Could not initialize Azure Auth, clientId is required as a parameter');
  }

  if (!authority) {
    throw new Error('Could not initialize Azure Auth, authority is required as a parameter');
  }

  userAgent = new UserAgentApplication({
    auth: {
      clientId: clientId,
      redirectUri: redirectUri,
      authority: authority
    },
    cache: {
      cacheLocation: 'localStorage',
      storeAuthStateInCookie: true
    }
  });
  return userAgent;
};
/** Returns the userAgent, must be initialized to return */

export var getUserAgentApplication = function getUserAgentApplication() {
  return userAgent;
};
/**
 * Returns an access token based on the scopes passed
 * @param {Array} scopes - scopes associated with the token
*/

export var getToken =
/*#__PURE__*/
function () {
  var _ref = _asyncToGenerator(
  /*#__PURE__*/
  _regeneratorRuntime.mark(function _callee(scopes) {
    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            return _context.abrupt("return", userAgent.acquireTokenSilent({
              scopes: _toConsumableArray(scopes)
            }));

          case 1:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  }));

  return function getToken(_x) {
    return _ref.apply(this, arguments);
  };
}();
/**
 * Returns the authenticated client for use in making calls to graph
 * @param {Object} accessToken - the access token returned from login
 * @returns {Object} client - the client used for graph calls
*/

export var getAuthenticatedClient = function getAuthenticatedClient(accessToken) {
  var client = Client.init({
    authProvider: function authProvider(done) {
      done(null, accessToken.accessToken);
    }
  });
  return client;
};
/**
 * Returns the user's details
 * @param {Array} scopes - scopes associated with the token
 * @returns {Object}  - the user information object from graph
*/

export var getUserDetails =
/*#__PURE__*/
function () {
  var _ref2 = _asyncToGenerator(
  /*#__PURE__*/
  _regeneratorRuntime.mark(function _callee2(scopes) {
    var accessToken, client, user;
    return _regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            _context2.next = 2;
            return getToken(scopes);

          case 2:
            accessToken = _context2.sent;
            client = getAuthenticatedClient(accessToken);
            _context2.next = 6;
            return client.api('/me').get();

          case 6:
            user = _context2.sent;
            return _context2.abrupt("return", user);

          case 8:
          case "end":
            return _context2.stop();
        }
      }
    }, _callee2);
  }));

  return function getUserDetails(_x2) {
    return _ref2.apply(this, arguments);
  };
}();
/**
 * Formats the API headers and appends the token
 * @param {bool} isAuthenticated - whether the user is logged in or not
 * @param {string} verb - GET, PUT, POST, PATCH, etc...
 * @param {Array} scopes - scopes associated with the token
 * @returns {Object} Returns the necessary http params for an authenticated or unauthenticated call
*/

export var formatAPIParams =
/*#__PURE__*/
function () {
  var _ref3 = _asyncToGenerator(
  /*#__PURE__*/
  _regeneratorRuntime.mark(function _callee3(isAuthenticated, verb, scopes) {
    var params, accessToken;
    return _regeneratorRuntime.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            params = {
              headers: {
                'Content-Type': 'application/json'
              },
              method: verb
            };

            if (!isAuthenticated) {
              _context3.next = 6;
              break;
            }

            _context3.next = 4;
            return getToken(scopes);

          case 4:
            accessToken = _context3.sent;
            params.headers.Authorization = "Bearer ".concat(accessToken.accessToken);

          case 6:
            return _context3.abrupt("return", params);

          case 7:
          case "end":
            return _context3.stop();
        }
      }
    }, _callee3);
  }));

  return function formatAPIParams(_x3, _x4, _x5) {
    return _ref3.apply(this, arguments);
  };
}();