import _regeneratorRuntime from "@babel/runtime/regenerator";
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import React from 'react';
import { useIsAuthenticated, useMsal } from '@azure/msal-react';
import Button from '../components/Button/Button';
export var msalConfig = function msalConfig(msal) {
  return {
    auth: {
      clientId: msal.CLIENT_ID,
      authority: msal.AUTHORITY,
      redirectUri: msal.REDIRECT_URI,
      navigateToLoginRequestUrl: msal.NAVIGATE_TO_LOGIN_REQUEST_URL,
      postLogoutRedirectUri: msal.POST_LOGOUT_REDIRECT_URI
    },
    cache: {
      // This configures where your cache will be stored
      cacheLocation: msal.CACHE_LOCATION,
      // Set this to "true" if you are having issues on IE11 or Edge
      storeAuthStateInCookie: msal.STORE_AUTH_STATE_IN_COOKIE
    }
  };
}; // Add the endpoints here for Microsoft Graph API services you'd like to use.

export var graphConfig = function graphConfig(msal) {
  return msal.GRAPH_ME_ENDPOINT;
}; // function handleLogin(instance) {

var handleLogin = function handleLogin(instance, msal) {
  instance.loginRedirect({
    scopes: msal.SCOPES
  }).catch(function (e) {
    // eslint-disable-next-line no-console
    console.error('handleLogin()', e);
  });
};
/**
   * Renders a button which, when selected, will open a popup for login
   */


export var SignInButton = function SignInButton(msal) {
  var _useMsal = useMsal(),
      instance = _useMsal.instance;

  return (
    /*#__PURE__*/
    React.createElement(Button, {
      style: {
        fontSize: '100%',
        fontWeight: '100',
        color: 'white',
        marginBottom: '3px'
      },
      variant: 'primary',
      onClick: function onClick() {
        return handleLogin(instance, msal);
      }
    }, "Sign In")
  );
};

function handleLogout(instance) {
  instance.logoutRedirect().catch(function (e) {
    // eslint-disable-next-line no-console
    console.error('handleLogout()', e);
  });
}
/**
 * Renders a button which, when selected, will open a popup for logout
 */


export var SignOutButton = function SignOutButton() {
  var _useMsal2 = useMsal(),
      instance = _useMsal2.instance;

  return (
    /*#__PURE__*/
    React.createElement(Button, {
      style: {
        fontSize: '100%',
        fontWeight: '100',
        color: 'white',
        marginBottom: '3px'
      },
      variant: 'primary',
      onClick: function onClick() {
        return handleLogout(instance);
      }
    }, "Sign out")
  );
};
export function callMsGraphAPI(_x, _x2) {
  return _callMsGraphAPI.apply(this, arguments);
}

function _callMsGraphAPI() {
  _callMsGraphAPI = _asyncToGenerator(
  /*#__PURE__*/
  _regeneratorRuntime.mark(function _callee2(accessToken, msal) {
    var headers, bearer, options;
    return _regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            headers = new Headers();
            bearer = "Bearer ".concat(accessToken);
            headers.append('Authorization', bearer);
            options = {
              method: 'GET',
              headers: headers
            };
            return _context2.abrupt("return", fetch(graphConfig(msal.msal), options).then(function (response) {
              return response.json();
            }) // eslint-disable-next-line no-console
            .catch(function (e) {
              return console.log('callMsGraphAPI()', e);
            }));

          case 5:
          case "end":
            return _context2.stop();
        }
      }
    }, _callee2);
  }));
  return _callMsGraphAPI.apply(this, arguments);
}

export var useMsalInstance = function useMsalInstance() {
  var _useMsal3 = useMsal(),
      instance = _useMsal3.instance,
      accounts = _useMsal3.accounts;

  var isAuthenticated = useIsAuthenticated();
  return {
    instance: instance,
    accounts: accounts,
    isAuthenticated: isAuthenticated
  };
};
export function formatAPIParams2(_x3, _x4, _x5) {
  return _formatAPIParams.apply(this, arguments);
}

function _formatAPIParams() {
  _formatAPIParams = _asyncToGenerator(
  /*#__PURE__*/
  _regeneratorRuntime.mark(function _callee3(payload, verb, scopes) {
    var params, app, appAccessToken;
    return _regeneratorRuntime.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            params = {
              headers: {
                'Content-Type': 'application/json'
              },
              method: verb
            };
            app = {
              scopes: scopes,
              account: payload.accounts[0]
            };
            appAccessToken = null;
            _context3.next = 5;
            return payload.instance.acquireTokenSilent(app).then(function (response) {
              appAccessToken = response.accessToken;
            });

          case 5:
            params.headers.Authorization = "Bearer ".concat(appAccessToken);
            return _context3.abrupt("return", params);

          case 7:
          case "end":
            return _context3.stop();
        }
      }
    }, _callee3);
  }));
  return _formatAPIParams.apply(this, arguments);
}

export function callMsGraphPicture(_x6, _x7) {
  return _callMsGraphPicture.apply(this, arguments);
}

function _callMsGraphPicture() {
  _callMsGraphPicture = _asyncToGenerator(
  /*#__PURE__*/
  _regeneratorRuntime.mark(function _callee4(accessToken, msal) {
    var headers, bearer, options, data, blobUrl, url;
    return _regeneratorRuntime.wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            headers = new Headers();
            bearer = "Bearer ".concat(accessToken);
            headers.append('Authorization', bearer);
            options = {
              method: 'GET',
              headers: headers
            };
            data = null;
            _context4.next = 7;
            return fetch("".concat(msal.GRAPH_ME_ENDPOINT, "/photos/48x48/$value"), options).then(function (response) {
              return response.blob();
            });

          case 7:
            data = _context4.sent;
            blobUrl = null;

            if (data != null) {
              url = window.URL || window.webkitURL;
              blobUrl = url.createObjectURL(data);
            }

            return _context4.abrupt("return", blobUrl);

          case 11:
          case "end":
            return _context4.stop();
        }
      }
    }, _callee4);
  }));
  return _callMsGraphPicture.apply(this, arguments);
}

export function callMsGraph(_x8) {
  return _callMsGraph.apply(this, arguments);
}

function _callMsGraph() {
  _callMsGraph = _asyncToGenerator(
  /*#__PURE__*/
  _regeneratorRuntime.mark(function _callee5(msal) {
    var graph, accessToken, graphData, profilePicture;
    return _regeneratorRuntime.wrap(function _callee5$(_context5) {
      while (1) {
        switch (_context5.prev = _context5.next) {
          case 0:
            graph = {
              scopes: msal.msal.SCOPES,
              account: msal.msalInstance.accounts[0]
            };
            accessToken = null;
            graphData = null;
            _context5.next = 5;
            return msal.msalInstance.instance.acquireTokenSilent(graph).then(function (response) {
              accessToken = response.accessToken;
            }).catch(function (e) {
              // eslint-disable-next-line no-console
              console.log('callMsGraph()', e);
              msal.msalInstance.instance.acquireTokenSilent(graph).then(function (response) {
                accessToken = response.accessToken;
              });
            });

          case 5:
            _context5.next = 7;
            return callMsGraphAPI(accessToken, msal);

          case 7:
            graphData = _context5.sent;
            _context5.next = 10;
            return callMsGraphPicture(accessToken, msal.msal);

          case 10:
            profilePicture = _context5.sent;
            // callMsGraphPicture(accessToken);
            graphData.profilePicture = profilePicture;
            return _context5.abrupt("return", graphData);

          case 13:
          case "end":
            return _context5.stop();
        }
      }
    }, _callee5);
  }));
  return _callMsGraph.apply(this, arguments);
}

export var appMsalToken =
/*#__PURE__*/
function () {
  var _ref = _asyncToGenerator(
  /*#__PURE__*/
  _regeneratorRuntime.mark(function _callee(input) {
    var _input$payload, apiScopes, msal, app, accessToken;

    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            _input$payload = input.payload, apiScopes = _input$payload.apiScopes, msal = _input$payload.msalConfig;
            app = {
              scopes: apiScopes,
              account: msal.msalInstance.accounts[0]
            };
            accessToken = null;
            _context.next = 5;
            return msal.msalInstance.instance.acquireTokenSilent(app).then(function (response) {
              accessToken = response.accessToken;
            }).catch(function () {
              // eslint-disable-next-line no-console
              msal.msalInstance.instance.acquireTokenSilent(app).then(function (response) {
                accessToken = response.accessToken;
              });
            });

          case 5:
            return _context.abrupt("return", accessToken);

          case 6:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  }));

  return function appMsalToken(_x9) {
    return _ref.apply(this, arguments);
  };
}();
export default {
  SignInButton: SignInButton,
  SignOutButton: SignOutButton,
  callMsGraphAPI: callMsGraphAPI,
  useMsalInstance: useMsalInstance,
  formatAPIParams2: formatAPIParams2,
  callMsGraph: callMsGraph,
  appMsalToken: appMsalToken
};