import T from 'prop-types';
import odiLogo from '../images/office-of-digital-innovation-logo.png';
export var route = T.shape({
  /** Unique identifier for route */
  key: T.string.isRequired,

  /** Name of path */
  name: T.string.isRequired,

  /** URL path to route (required for internal links) */
  path: T.string,

  /** URL path to route (required for external links) */
  href: T.string,

  /** If route should be hidden from navigation menus */
  hidden: T.bool,

  /** If route needs to exatcly match */
  exact: T.bool,

  /** Icon to display in avigation menus */
  icon: T.string,

  /** Component to render (required for internal links) */
  component: T.func
});
export var contactLink = T.shape({
  /** Text to render */
  text: T.string.isRequired,

  /** Internal link to navigate to */
  to: T.string,

  /** External link to navigate to */
  href: T.string
});
export var contactLinkDefault = {
  text: 'Contact Us',
  href: 'https://cdt.ca.gov/support/'
};
export var brandingLogo = T.shape({
  /** Source of image */
  src: T.string.isRequired,

  /** Alt description of image */
  alt: T.string.isRequired,

  /** Internal link to navigate to */
  to: T.string,

  /** External link to navigate to */
  href: T.string
});
export var brandingLogoDefault = {
  src: odiLogo,
  alt: 'Office of Digital Innovation logo',
  href: 'https://cdt.ca.gov/'
};
export var option = T.shape({
  /** Label to render for option */
  label: T.string.isRequired,

  /** Internal value of option */
  value: T.oneOfType([T.string, T.bool, T.number])
});
export var footerLinks = T.arrayOf(T.shape({
  /** Text to render */
  text: T.string.isRequired,

  /** Internal link to navigate to */
  to: T.string,

  /** External link to navigate to */
  href: T.string
}));
export var footerLinksDefault = [{
  href: 'https://www.ca.gov/use/',
  text: 'Conditions of Use'
}, {
  href: 'https://www.ca.gov/privacy-policy/',
  text: 'Privacy Policy'
}, {
  href: 'https://www.ca.gov/accessibility/',
  text: 'Accessibility'
}];
export var socialLinks = T.arrayOf(T.shape({
  /** icon to render */
  iconProps: T.shape({
    name: T.string,
    srOnly: T.string
  }).isRequired,

  /** Internal link to navigate to */
  to: T.string,

  /** External link to navigate to */
  href: T.string
}));
export var socialLinksDefault = [{
  href: 'https://www.flickr.com/groups/californiagovernment',
  iconProps: {
    name: 'flickr',
    srOnly: 'Flickr'
  }
}, {
  href: 'https://www.pinterest.com/cagovernment',
  iconProps: {
    name: 'pinterest',
    srOnly: 'Pinterest'
  }
}, {
  href: 'https://twitter.com/cagovernment',
  iconProps: {
    name: 'twitter',
    srOnly: 'Twitter'
  }
}, {
  href: 'https://www.youtube.com/user/californiagovernment',
  iconProps: {
    name: 'youtube',
    srOnly: 'YouTube'
  }
}];