import * as validate from './validate';
describe('validate utils', function () {
  describe('isEmptyText', function () {
    it('should return an error for non string or empty values', function () {
      ['', null, undefined, {}].forEach(function (value) {
        expect(validate.isEmptyText(value)).toBeDefined();
      });
    });
    it('should return nothing for non empty strings', function () {
      var values = ['!@$&%&^%61527[]+_P{p]9', 'test string'];
      values.forEach(function (value) {
        expect(validate.isEmptyText(value)).toBeUndefined();
      });
    });
  });
  describe('isEmptyRadio', function () {
    it('should return an error for empty radios', function () {
      expect(validate.isEmptyRadio(undefined)).toBeDefined();
    });
    it('should return nothing for all other values', function () {
      expect(validate.isEmptyRadio('abc')).toBeUndefined();
      expect(validate.isEmptyRadio('123')).toBeUndefined();
      expect(validate.isEmptyRadio(0)).toBeUndefined();
    });
  });
  describe('isEmptyCheck', function () {
    it('should return an error for empty checks', function () {
      expect(validate.isEmptyCheck(undefined)).toBeDefined();
      expect(validate.isEmptyCheck([])).toBeDefined();
    });
    it('should return an nothing for valid checks', function () {
      expect(validate.isEmptyCheck([1, 2, 3])).toBeUndefined();
    });
  });
  describe('isEmptyFile', function () {
    it('should return an error for empty files', function () {
      expect(validate.isEmptyFile(undefined)).toBeDefined();
    });
    it('should return an error for invalid files', function () {
      var file = {
        otherStuff: 'need a name...'
      };
      expect(validate.isEmptyFile(file)).toBeDefined();
    });
    it('should return nothing for a single valid file', function () {
      var file = {
        name: 'test-file'
      };
      expect(validate.isEmptyFile(file)).toBeUndefined();
    });
    it('should return nothing for a multiple valid file', function () {
      var files = [{
        name: 'test-file-1'
      }, {
        name: 'test-file-2'
      }];
      expect(validate.isEmptyFile(files)).toBeUndefined();
    });
  });
  describe('isValidEmail', function () {
    it('should return an error for invalid emails', function () {
      expect(validate.isValidEmail('abc.com')).toBeDefined();
    });
    it('should return nothing for valid emails', function () {
      expect(validate.isValidEmail('test@domain.com')).toBeUndefined();
    });
  });
  describe('isValidPhone', function () {
    it('should return an error for invalid phone numbers', function () {
      expect(validate.isValidPhone('123')).toBeDefined();
    });
    it('should return nothing for valid phone numbers', function () {
      expect(validate.isValidPhone('123-456-7890')).toBeUndefined();
    });
  });
  describe('isValidDate', function () {
    it('should return an error for invalid dates', function () {
      expect(validate.isValidDate('not a valid date')).toBeDefined();
      expect(validate.isValidDate(null)).toBeDefined();
    });
    it('should return nothing for valid phone numbers', function () {
      expect(validate.isValidDate('1969-02-05')).toBeUndefined();
      expect(validate.isValidDate(new Date())).toBeUndefined();
    });
  });
  describe('isValidZip', function () {
    it('should return an error for invalid zips', function () {
      expect(validate.isValidZip('123')).toBeDefined();
      expect(validate.isValidZip('abcde')).toBeDefined();
    });
    it('should return nothing for valid zips and empty', function () {
      expect(validate.isValidZip('12345')).toBeUndefined();
      expect(validate.isValidZip('')).toBeUndefined();
    });
  });
  describe('isOnlyNumbers', function () {
    it('should return an error for invalid strings', function () {
      expect(validate.isOnlyNumbers('123asd')).toBeDefined();
      expect(validate.isOnlyNumbers('abcde')).toBeDefined();
      expect(validate.isOnlyNumbers('^%^%dashjdgjas76857')).toBeDefined();
    });
    it('should return nothing for valid strings and empty', function () {
      expect(validate.isOnlyNumbers('12345')).toBeUndefined();
      expect(validate.isOnlyNumbers('123')).toBeUndefined();
      expect(validate.isOnlyNumbers('1238797')).toBeUndefined();
      expect(validate.isValidZip('')).toBeUndefined();
    });
  });
  describe('isEmptyOrNull', function () {
    it('should return required if empty or null', function () {
      expect(validate.isEmptyOrNull('')).toBeDefined();
      expect(validate.isEmptyOrNull(null)).toBeDefined();
      expect(validate.isEmptyOrNull()).toBeDefined();
      expect(validate.isEmptyOrNull([])).toBeDefined();
      expect(validate.isEmptyOrNull({})).toBeDefined();
    });
    it('should return nothing if not empty or null', function () {
      expect(validate.isEmptyOrNull({
        name: 'test-name'
      })).toBeUndefined();
      expect(validate.isOnlyNumbers('12345')).toBeUndefined();
      expect(validate.isOnlyNumbers(['12345'])).toBeUndefined();
    });
  });
});